# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: common.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63ommon.proto\x12\x06\x61llego\x1a\x1fgoogle/protobuf/timestamp.proto\",\n\x14HardwareUUIDResponse\x12\x14\n\x0chardwareUUID\x18\x02 \x02(\t\"@\n\x14OfflineLicenseStatus\x12\x12\n\nisVerified\x18\x01 \x02(\x08\x12\x14\n\x0chardwareUUID\x18\x02 \x02(\t\"C\n\x0f\x46irmwareVersion\x12\x0c\n\x04\x64\x61te\x18\x01 \x02(\t\x12\x10\n\x08majorRev\x18\x02 \x02(\x05\x12\x10\n\x08minorRev\x18\x03 \x02(\x05\"\x8a\x01\n\x10RadixEnvironment\x12\x0f\n\x07version\x18\x01 \x02(\t\x12\x14\n\x0cuserDataPath\x18\x02 \x02(\t\x12\x30\n\x0f\x66irmwareVersion\x18\x03 \x02(\x0b\x32\x17.allego.FirmwareVersion\x12\x1d\n\x15userCustomSensorsPath\x18\x04 \x02(\t\"O\n\rStartupStatus\x12\x19\n\x11isStartupComplete\x18\x01 \x02(\x08\x12#\n\x05stage\x18\x02 \x02(\x0e\x32\x14.allego.StartupStage\"!\n\x0fStandardRequest\x12\x0e\n\x06regStr\x18\x02 \x03(\t\"/\n\rStandardReply\x12\x0e\n\x06\x65rrMsg\x18\x01 \x01(\t\x12\x0e\n\x06regStr\x18\x02 \x03(\t\"&\n\rDACOffRequest\x12\x15\n\rstreamGroupId\x18\x01 \x01(\t\"\xba\x01\n\x13WorkspaceDescriptor\x12\n\n\x02iD\x18\x01 \x02(\t\x12!\n\x03\x61pp\x18\x02 \x02(\x0e\x32\x14.allego.WorkspaceApp\x12\x12\n\nisModified\x18\x03 \x02(\x08\x12\x19\n\x11timestampLastUsed\x18\x04 \x02(\t\x12\x19\n\x11timestampModified\x18\x05 \x02(\t\x12*\n\nannotation\x18\x06 \x02(\x0b\x32\x16.allego.AnnotateBundle\"\xdb\x01\n\x17WorkspaceControlRequest\x12&\n\x03\x63md\x18\x01 \x02(\x0e\x32\x19.allego.WorkspaceCommands\x12\x13\n\x0bworkspaceID\x18\x02 \x01(\t\x12*\n\nannotation\x18\x03 \x01(\x0b\x32\x16.allego.AnnotateBundle\x12\x1a\n\x12targetFullFileName\x18\x04 \x01(\t\x12\x18\n\x10isForceOverwrite\x18\x05 \x01(\x08\x12!\n\x03\x61pp\x18\x06 \x02(\x0e\x32\x14.allego.WorkspaceApp\"\xd3\x01\n\x13GetWorkspaceRequest\x12)\n\x03\x63md\x18\x01 \x02(\x0e\x32\x1c.allego.GetWorkspaceCommands\x12\x13\n\x0bworkspaceID\x18\x02 \x01(\t\x12\x14\n\x0cworkspaceDir\x18\x03 \x01(\t\x12%\n\x07\x61ppMask\x18\x04 \x01(\x0e\x32\x14.allego.WorkspaceApp\x12,\n\x0c\x61nnotateMask\x18\x05 \x01(\x0b\x32\x16.allego.AnnotateBundle\x12\x11\n\tisBrowser\x18\x06 \x01(\x08\"\xab\x01\n\x11GetWorkspaceReply\x12\x43\n\rworkspaceDesc\x18\x01 \x03(\x0b\x32,.allego.GetWorkspaceReply.WorkspaceDescEntry\x1aQ\n\x12WorkspaceDescEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.allego.WorkspaceDescriptor:\x02\x38\x01\"`\n\x18GetRadiensServersRequest\x12\x15\n\rhostIPaddress\x18\x01 \x02(\t\x12-\n\nserverType\x18\x02 \x01(\x0e\x32\x19.allego.RadiensServerType\"\x97\x02\n\nServerSpec\x12\x0c\n\x04host\x18\x01 \x02(\t\x12\x0b\n\x03pid\x18\x02 \x02(\x05\x12\x30\n\x07service\x18\x03 \x03(\x0b\x32\x1f.allego.ServerSpec.ServiceEntry\x12\x30\n\x05spawn\x18\x04 \x01(\x0b\x32!.allego.ServerSpec.SpawnedProcess\x1a\x1b\n\x0bGrpcService\x12\x0c\n\x04port\x18\x01 \x02(\x05\x1a\x1d\n\x0eSpawnedProcess\x12\x0b\n\x03pid\x18\x01 \x03(\x05\x1aN\n\x0cServiceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.allego.ServerSpec.GrpcService:\x02\x38\x01\"j\n\x13RadiensServersReply\x12(\n\x0c\x61llegoserver\x18\x01 \x03(\x0b\x32\x12.allego.ServerSpec\x12)\n\rradiensserver\x18\x02 \x03(\x0b\x32\x12.allego.ServerSpec\"-\n\x14SignalGroupIDRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\"\xc4\x01\n\tSignalMap\x12\x0f\n\x07siteIdx\x18\x01 \x03(\x05\x12\x13\n\x0b\x63ompSiteNum\x18\x02 \x03(\t\x12\x13\n\x0bposProbeUmX\x18\x03 \x03(\x01\x12\x13\n\x0bposProbeUmY\x18\x04 \x03(\x01\x12\x13\n\x0bposProbeUmZ\x18\x05 \x03(\x01\x12\x14\n\x0cposTissueUmX\x18\x06 \x03(\x01\x12\x14\n\x0cposTissueUmY\x18\x07 \x03(\x01\x12\x14\n\x0cposTissueUmZ\x18\x08 \x03(\x01\x12\x10\n\x08sensorID\x18\t \x03(\t\"=\n\x10GPIOChannelCount\x12\x0c\n\x04nAux\x18\x01 \x02(\x05\x12\x0c\n\x04nDin\x18\x02 \x02(\x05\x12\r\n\x05nDout\x18\x03 \x02(\x05\"D\n\x10PortChannelCount\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\x12\x14\n\x0c\x63hannelCount\x18\x02 \x02(\x05\"Q\n\x0eSetPortRequest\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\x12\x10\n\x08probeUID\x18\x02 \x02(\t\x12\x11\n\thstageUID\x18\x03 \x02(\t\"\x94\x03\n\x11HDSnapshotRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12=\n\npriSignals\x18\x03 \x01(\x0b\x32).allego.HDSnapshotRequest.SelectedSignals\x12=\n\nauxSignals\x18\x04 \x01(\x0b\x32).allego.HDSnapshotRequest.SelectedSignals\x12=\n\ndinSignals\x18\x05 \x01(\x0b\x32).allego.HDSnapshotRequest.SelectedSignals\x12>\n\x0b\x64outSignals\x18\x06 \x01(\x0b\x32).allego.HDSnapshotRequest.SelectedSignals\x12\x1b\n\x13isNotApplyDSPstage2\x18\x07 \x01(\x08\x12\x13\n\x0b\x63omponentID\x18\x08 \x01(\t\x1a&\n\x0fSelectedSignals\x12\x13\n\x0bntvChanIdxs\x18\x01 \x03(\x05\"\x96\x01\n\x12HDSnapshotRequest2\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x1d\n\x02tR\x18\x02 \x02(\x0b\x32\x11.allego.TimeRange\x12)\n\x07selMode\x18\x03 \x01(\x0e\x32\x18.allego.TimeRangeSelMode\x12#\n\x06sigSel\x18\x04 \x01(\x0b\x32\x13.allego.SigSelector\"L\n\x15RadiensPyGraphicsArgs\x12\x12\n\ngraphicsID\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0f\n\x07\x66igSize\x18\x03 \x03(\x03\"\xdd\x02\n\nPSDRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x1d\n\x02tR\x18\x02 \x02(\x0b\x32\x11.allego.TimeRange\x12)\n\x07selMode\x18\x03 \x02(\x0e\x32\x18.allego.TimeRangeSelMode\x12!\n\x05stype\x18\x04 \x02(\x0e\x32\x12.allego.SignalType\x12\x0f\n\x07ntvIdxs\x18\x05 \x03(\x03\x12\x12\n\nresampleFs\x18\x06 \x01(\x01\x12&\n\x07wdwType\x18\x07 \x01(\x0e\x32\x15.allego.PSDWindowType\x12#\n\x07scaling\x18\x08 \x01(\x0e\x32\x12.allego.PSDScaling\x12\x11\n\tfreqRange\x18\t \x03(\x01\x12\x14\n\x0c\x63ollapseFreq\x18\n \x01(\x08\x12\x11\n\tdeltaFreq\x18\x0b \x01(\x01\x12\x0c\n\x04path\x18\r \x01(\t\x12\x13\n\x0bisReturnPSD\x18\x0e \x01(\x08\"\xa1\x02\n\x03PSD\x12\x11\n\tdsourceID\x18\x01 \x01(\t\x12\x1f\n\x02sG\x18\x03 \x02(\x0b\x32\x13.allego.SignalGroup\x12!\n\x05stype\x18\x04 \x02(\x0e\x32\x12.allego.SignalType\x12\x1d\n\x02tR\x18\x05 \x02(\x0b\x32\x11.allego.TimeRange\x12 \n\x03psd\x18\x06 \x02(\x0b\x32\x13.allego.DenseMatrix\x12\x0c\n\x04\x66req\x18\x07 \x03(\x01\x12\x14\n\x0c\x66reqBinWidth\x18\x08 \x02(\x01\x12\x11\n\tfreqRange\x18\x0b \x03(\x01\x12&\n\x07wdwType\x18\t \x01(\x0e\x32\x15.allego.PSDWindowType\x12#\n\x07scaling\x18\n \x01(\x0e\x32\x12.allego.PSDScaling\"e\n\x18RadiensPyGraphicsRequest\x12\x1c\n\x07psdData\x18\x01 \x01(\x0b\x32\x0b.allego.PSD\x12+\n\x04\x61rgs\x18\x02 \x01(\x0b\x32\x1d.allego.RadiensPyGraphicsArgs\"^\n\x0bSigSelector\x12\x12\n\nampNtvIdxs\x18\x01 \x03(\x03\x12\x12\n\nainNtvIdxs\x18\x02 \x03(\x03\x12\x12\n\ndinNtvIdxs\x18\x03 \x03(\x03\x12\x13\n\x0b\x64outNtvIdxs\x18\x04 \x03(\x03\"]\n\x0eHDSnapshotMeta\x12\x11\n\tglobalMin\x18\x04 \x02(\x01\x12\x11\n\tglobalMax\x18\x05 \x02(\x01\x12%\n\x08sigGroup\x18\x06 \x01(\x0b\x32\x13.allego.SignalGroup\"\x9f\x02\n\nHDSnapshot\x12$\n\x04meta\x18\x01 \x02(\x0b\x32\x16.allego.HDSnapshotMeta\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x13\n\x0btimeSamples\x18\x03 \x02(\x0c\x12#\n\x07signals\x18\x04 \x02(\x0b\x32\x12.allego.RawSignals\x12&\n\npriSignals\x18\x05 \x01(\x0b\x32\x12.allego.RawSignals\x12&\n\nauxSignals\x18\x06 \x01(\x0b\x32\x12.allego.RawSignals\x12&\n\ndinSignals\x18\x07 \x01(\x0b\x32\x12.allego.RawSignals\x12\'\n\x0b\x64outSignals\x18\x08 \x01(\x0b\x32\x12.allego.RawSignals\"@\n\x0bHDSnapshot2\x12\x11\n\tdsourceID\x18\x01 \x01(\t\x12\x1e\n\x04sigs\x18\x02 \x02(\x0b\x32\x10.allego.Signals2\"\xa8\x05\n\x11GetSignalsRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x37\n\x06params\x18\x02 \x02(\x0b\x32\'.allego.GetSignalsRequest.GetSigsParams\x1a\xc2\x04\n\rGetSigsParams\x12\x11\n\ttimeRange\x18\x01 \x03(\x01\x12\x0e\n\x06wdwSec\x18\x02 \x02(\x01\x12\x14\n\x0c\x63hanHeightPx\x18\x03 \x02(\x01\x12\x10\n\x08\x61mpFsrUv\x18\x04 \x02(\x01\x12\x17\n\x0fplotWidthPoints\x18\x05 \x02(\x01\x12\x11\n\tgpioOnTop\x18\x06 \x02(\x08\x12\x0f\n\x07\x61inFsrV\x18\x07 \x02(\x01\x12\x13\n\x0b\x63omponentID\x18\x08 \x02(\t\x12\x37\n\x0f\x61mpResampleType\x18\t \x01(\x0e\x32\x17.allego.ResampleRoutine:\x05NAIVE\x12\x11\n\tisHeatmap\x18\n \x02(\x08\x12\x1b\n\x13isNotApplyDSPstage2\x18\x0b \x01(\x08\x12\x13\n\x0b\x63lipToRange\x18\x0c \x02(\x08\x12\x17\n\x0f\x62\x61ndpassLowFreq\x18\r \x01(\x01\x12\x18\n\x10\x62\x61ndpassHighFreq\x18\x0e \x01(\x01\x12\x12\n\nntvChanIdx\x18\x0f \x01(\x01\x12#\n\x07sigType\x18\x10 \x01(\x0e\x32\x12.allego.SignalType\x12\x37\n\x0f\x61inResampleType\x18\x11 \x01(\x0e\x32\x17.allego.ResampleRoutine:\x05NAIVE\x12\x37\n\x0f\x64inResampleType\x18\x12 \x01(\x0e\x32\x17.allego.ResampleRoutine:\x05NAIVE\x12\x38\n\x10\x64outResampleType\x18\x13 \x01(\x0e\x32\x17.allego.ResampleRoutine:\x05NAIVE\"[\n\nRawSignals\x12\r\n\x05shape\x18\x01 \x03(\x05\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12\x0c\n\x04\x64\x61ta\x18\x03 \x02(\x0c\x12\x1d\n\x02tR\x18\x04 \x01(\x0b\x32\x11.allego.TimeRange\"\xe7\x01\n\x08Signals2\x12\x1f\n\x02sG\x18\x01 \x02(\x0b\x32\x13.allego.SignalGroup\x12\x1d\n\x02tR\x18\x02 \x02(\x0b\x32\x11.allego.TimeRange\x12%\n\x03\x61mp\x18\x03 \x01(\x0b\x32\x18.allego.RadixMatrixBytes\x12%\n\x03\x61in\x18\x04 \x01(\x0b\x32\x18.allego.RadixMatrixBytes\x12%\n\x03\x64in\x18\x05 \x01(\x0b\x32\x18.allego.RadixMatrixBytes\x12&\n\x04\x64out\x18\x06 \x01(\x0b\x32\x18.allego.RadixMatrixBytes\"K\n\x16ListSensorSpecsRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x1a\n\x12showOfflineDevices\x18\x02 \x01(\x08\"\x85\x02\n\x14ListSensorSpecsReply\x12\x41\n\x06probes\x18\x01 \x03(\x0b\x32\x31.allego.ListSensorSpecsReply.SpecWithChannelCount\x12\x45\n\nheadstages\x18\x02 \x03(\x0b\x32\x31.allego.ListSensorSpecsReply.SpecWithChannelCount\x12\'\n\x05ports\x18\x03 \x03(\x0b\x32\x18.allego.PortChannelCount\x1a:\n\x14SpecWithChannelCount\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x14\n\x0c\x63hannelCount\x18\x02 \x02(\x05\"d\n\x16ListDataSourcesRequest\x12\x11\n\tdirectory\x18\x01 \x02(\t\x12&\n\x06sortBy\x18\x02 \x01(\x0e\x32\x16.allego.DataSourceSort\x12\x0f\n\x07\x64irList\x18\x03 \x03(\t\"\x1c\n\x07SortMap\x12\x11\n\tsorterIds\x18\x01 \x03(\t\">\n\x16GetSignalGroupIDsReply\x12\x12\n\ncontinuous\x18\x01 \x03(\t\x12\x10\n\x08\x64iscrete\x18\x02 \x03(\t\"\xa0\x01\n\x13GetSorterIDMapReply\x12\x43\n\x0csigToSortMap\x18\x01 \x03(\x0b\x32-.allego.GetSorterIDMapReply.SigToSortMapEntry\x1a\x44\n\x11SigToSortMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.allego.SortMap:\x02\x38\x01\"\xaf\x01\n\nDataSource\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0c\n\x04\x64\x61te\x18\x02 \x02(\t\x12\x17\n\x0f\x64urationSeconds\x18\x03 \x02(\x01\x12\x17\n\x0f\x64urationMinutes\x18\x04 \x02(\x01\x12\x15\n\rdurationHours\x18\x05 \x02(\x01\x12(\n\x08\x66ileType\x18\x06 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12\x12\n\nnumSignals\x18\x07 \x02(\x05\"\x88\x01\n\x0e\x46ileDescriptor\x12\x0c\n\x04path\x18\x01 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x02 \x02(\t\x12(\n\x08\x66ileType\x18\x03 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12\x13\n\x0b\x66ileNameUID\x18\x04 \x01(\t\x12\x17\n\x0fisLiveRecording\x18\x05 \x01(\x08\"\xd0\x01\n\x08TimeSpec\x12\x30\n\ttimeRange\x18\x01 \x01(\x0b\x32\x1b.allego.TimeSpec.TimeRangeLH\x00\x12:\n\x0etimestampRange\x18\x02 \x01(\x0b\x32 .allego.TimeSpec.TimestampRangeLH\x00\x1a\x1f\n\nTimeRangeL\x12\x11\n\ttimeRange\x18\x01 \x03(\x01\x1a)\n\x0fTimestampRangeL\x12\x16\n\x0etimestampRange\x18\x01 \x03(\x03\x42\n\n\x08timeDesc\"\xbe\x01\n\nSignalSpec\x12.\n\x07siteNum\x18\x01 \x01(\x0b\x32\x1b.allego.SignalSpec.SiteNumLH\x00\x12\x34\n\nntvChanIdx\x18\x02 \x01(\x0b\x32\x1e.allego.SignalSpec.NtvChanIdxLH\x00\x1a\x1b\n\x08SiteNumL\x12\x0f\n\x07siteNum\x18\x01 \x03(\x05\x1a!\n\x0bNtvChanIdxL\x12\x12\n\nntvChanIdx\x18\x01 \x03(\x05\x42\n\n\x08siteDesc\"\x8c\x06\n\rChannelRecord\x12\x10\n\x08\x63hanName\x18\x01 \x02(\t\x12$\n\x08\x63hanType\x18\x02 \x02(\x0e\x32\x12.allego.SignalType\x12\x12\n\nntvChanIdx\x18\x03 \x02(\x05\x12\x0f\n\x07siteNum\x18\x04 \x02(\x05\x12\x15\n\rcolorGroupIdx\x18\x05 \x02(\x05\x12\x12\n\nisSelected\x18\x06 \x02(\x08\x12\x13\n\x0bisAudioLeft\x18\x07 \x02(\x08\x12\x1a\n\x04port\x18\x08 \x02(\x0e\x32\x0c.allego.Port\x12\x11\n\tsiteShape\x18\t \x02(\t\x12\x10\n\x08siteCtrX\x18\n \x02(\x01\x12\x10\n\x08siteCtrY\x18\x0b \x02(\x01\x12\x10\n\x08siteCtrZ\x18\x0c \x02(\x01\x12\x13\n\x0bsiteLimXMin\x18\r \x02(\x01\x12\x13\n\x0bsiteLimXMax\x18\x0e \x02(\x01\x12\x13\n\x0bsiteLimYMin\x18\x0f \x02(\x01\x12\x13\n\x0bsiteLimYMax\x18\x10 \x02(\x01\x12\x13\n\x0bsiteLimZMin\x18\x11 \x02(\x01\x12\x13\n\x0bsiteLimZMax\x18\x12 \x02(\x01\x12\x13\n\x0bsiteCtrTcsX\x18\x13 \x02(\x01\x12\x13\n\x0bsiteCtrTcsY\x18\x14 \x02(\x01\x12\x13\n\x0bsiteCtrTcsZ\x18\x15 \x02(\x01\x12\x13\n\x0bsensorUnits\x18\x16 \x02(\t\x12\x0e\n\x06\x61\x62sIdx\x18\x17 \x02(\x05\x12\x14\n\x0cisAudioRight\x18\x18 \x02(\x08\x12\x12\n\nsysChanIdx\x18\x19 \x02(\x05\x12\x17\n\x0fsiteAreaMicron2\x18\x1a \x01(\x01\x12\x11\n\tscsToTcsX\x18\x1b \x01(\x01\x12\x11\n\tscsToTcsY\x18\x1c \x01(\x01\x12\x11\n\tscsToTcsZ\x18\x1d \x01(\x01\x12\x10\n\x08sensorID\x18\x1e \x01(\t\x12\x0f\n\x07probeID\x18\x1f \x01(\t\x12\x13\n\x0bheadstageID\x18  \x01(\t\x12\x13\n\x0b\x64\x61tasetRidx\x18! \x01(\x05\x12\x13\n\x0b\x64\x61tasetAidx\x18\" \x01(\x05\x12\x13\n\x0bntvChanName\x18# \x01(\t\x12\x11\n\tsensorUID\x18$ \x01(\t\x12\x11\n\tsensorIdx\x18% \x01(\x05\"\x1f\n\x07XYCoord\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\"+\n\x08XYZCoord\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\t\n\x01z\x18\x03 \x02(\x01\"\x81\x03\n\x06Sensor\x12\x0f\n\x07probeId\x18\x01 \x02(\t\x12\x13\n\x0bheadstageId\x18\x02 \x02(\t\x12+\n\twireframe\x18\x03 \x02(\x0b\x32\x18.allego.Sensor.WireFrame\x12\x0c\n\x04xMin\x18\x04 \x02(\x01\x12\x0c\n\x04xMax\x18\x05 \x02(\x01\x12\x0c\n\x04yMin\x18\x06 \x02(\x01\x12\x0c\n\x04yMax\x18\x07 \x02(\x01\x12+\n\x08position\x18\x08 \x02(\x0b\x32\x19.allego.SensorPositionTcs\x12\x11\n\tsensorUID\x18\t \x01(\t\x12\x18\n\x10\x63onnectionNtvIdx\x18\n \x01(\x05\x12\x10\n\x08numSites\x18\x0b \x02(\x05\x12\x11\n\tsensorIdx\x18\x0c \x01(\x05\x1am\n\tWireFrame\x12\x1c\n\x03vtx\x18\x01 \x03(\x0b\x32\x0f.allego.XYCoord\x12 \n\x07vtxXlim\x18\x02 \x02(\x0b\x32\x0f.allego.XYCoord\x12 \n\x07vtxYlim\x18\x03 \x02(\x0b\x32\x0f.allego.XYCoord\"\x98\x02\n\x0eSensorPortSpec\x12\x1f\n\x07sensorA\x18\x01 \x03(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorB\x18\x02 \x03(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorC\x18\x03 \x03(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorD\x18\x04 \x03(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorE\x18\x05 \x03(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorF\x18\x06 \x03(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorG\x18\x07 \x03(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorH\x18\x08 \x03(\x0b\x32\x0e.allego.Sensor\"t\n\x10SignalGroupUnits\x12\x32\n\x05units\x18\x01 \x03(\x0b\x32#.allego.SignalGroupUnits.UnitsEntry\x1a,\n\nUnitsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\x9a\x02\n\x0bSignalGroup\x12\'\n\x08\x63hannels\x18\x01 \x03(\x0b\x32\x15.allego.ChannelRecord\x12.\n\x0esensorPortSpec\x18\x02 \x02(\x0b\x32\x16.allego.SensorPortSpec\x12\x12\n\ndatasetUID\x18\x03 \x01(\t\x12\x10\n\x08sampFreq\x18\x04 \x01(\x01\x12\x13\n\x0bsourceLabel\x18\x05 \x01(\t\x12\x19\n\x11neighborMaxRadius\x18\x06 \x01(\x01\x12-\n\x0bsignalUnits\x18\x07 \x01(\x0b\x32\x18.allego.SignalGroupUnits\x12\x13\n\x0bhasDiscrete\x18\x08 \x01(\x08\x12\x18\n\x10hasContinuousAmp\x18\t \x01(\x08\"\x87\x01\n\x18\x43reateSignalGroupRequest\x12\x16\n\x0e\x64\x61taSourceName\x18\x01 \x02(\t\x12\x16\n\x0e\x64\x61taSourcePath\x18\x02 \x02(\t\x12$\n\x04type\x18\x03 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12\x15\n\rstreamGroupId\x18\x04 \x02(\t\"s\n\tSubOpSort\x12)\n\x04sort\x18\x01 \x03(\x0e\x32\x1b.allego.SubOpSort.SortField\";\n\tSortField\x12\x0e\n\nSITE_CTR_X\x10\x00\x12\x0e\n\nSITE_CTR_Y\x10\x01\x12\x0e\n\nSITE_CTR_Z\x10\x02\"\xa5\x03\n\x18UpdateSignalGroupRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12=\n\toperation\x18\x02 \x02(\x0e\x32*.allego.UpdateSignalGroupRequest.Operation\x12\x42\n\taddRemove\x18\x03 \x01(\x0e\x32-.allego.UpdateSignalGroupRequest.SubOperationH\x00\x12#\n\x06sortOp\x18\x04 \x01(\x0b\x32\x11.allego.SubOpSortH\x00\x12\x16\n\nntvChanIdx\x18\x05 \x03(\x05\x42\x02\x10\x01\x12&\n\nsignalType\x18\x06 \x02(\x0e\x32\x12.allego.SignalType\x12\x11\n\tpropagate\x18\x07 \x01(\x08\"B\n\tOperation\x12\t\n\x05\x43OLOR\x10\x00\x12\n\n\x06SELECT\x10\x01\x12\x14\n\x10\x44\x45PRECATED_AUDIO\x10\x02\x12\x08\n\x04SORT\x10\x03\"#\n\x0cSubOperation\x12\x07\n\x03\x41\x44\x44\x10\x00\x12\n\n\x06REMOVE\x10\x01\x42\x0e\n\x0csubOperation\"T\n\x14SliceSignalGroupSpec\x12\x0e\n\x06sortBy\x18\x01 \x02(\t\x12\r\n\x05\x64\x65lim\x18\x02 \x02(\t\x12\x1d\n\x02tR\x18\x03 \x01(\x0b\x32\x11.allego.TimeRange\"X\n\x17SliceSignalGroupRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12*\n\x04spec\x18\x02 \x02(\x0b\x32\x1c.allego.SliceSignalGroupSpec\"\x88\x01\n\x15SliceSignalGroupReply\x12\x11\n\tdsourceID\x18\x01 \x01(\t\x12*\n\x04spec\x18\x02 \x02(\x0b\x32\x1c.allego.SliceSignalGroupSpec\x12\x1f\n\x02sG\x18\x03 \x02(\x0b\x32\x13.allego.SignalGroup\x12\x0f\n\x07outcome\x18\x04 \x02(\t\"\x0f\n\rLicenseStatus\"u\n\x12SetDSPGroupRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\"\n\x05stage\x18\x02 \x02(\x0e\x32\x13.allego.FilterStage\x12$\n\tdspParams\x18\x03 \x03(\x0b\x32\x11.allego.DSPParams\"\xac\x03\n\tDSPParams\x12\x1d\n\x04type\x18\x01 \x02(\x0e\x32\x0f.allego.DSPType\x12\"\n\x05stage\x18\x02 \x02(\x0e\x32\x13.allego.FilterStage\x12\x0e\n\x04\x66req\x18\x03 \x01(\x01H\x00\x12\x36\n\x0c\x66reqSpecBand\x18\x04 \x01(\x0b\x32\x1e.allego.DSPParams.FreqSpecBandH\x00\x12\x17\n\rrefNtvChanIdx\x18\x08 \x01(\x05H\x00\x12\x16\n\x0enotchBandwidth\x18\x05 \x01(\x01\x12\x11\n\tuserLabel\x18\x06 \x02(\t\x12\x1a\n\x04port\x18\x07 \x02(\x0e\x32\x0c.allego.Port\x12\x18\n\x10targetNtvChanIdx\x18\t \x01(\x01\x12\r\n\x05isAux\x18\n \x02(\x08\x12\x12\n\nauxChanIdx\x18\x0b \x01(\x05\x12\x13\n\x0b\x66ilterOrder\x18\x0c \x01(\x05\x12\x11\n\tzeroPhase\x18\r \x01(\x08\x12\x10\n\x08\x66orceSOS\x18\x0e \x01(\x08\x1a\x31\n\x0c\x46reqSpecBand\x12\x0f\n\x07lowFreq\x18\x01 \x02(\x01\x12\x10\n\x08highFreq\x18\x02 \x02(\x01\x42\n\n\x08\x66reqSpec\"\xad\x01\n\x08\x44SPGroup\x12#\n\x08hardware\x18\x01 \x03(\x0b\x32\x11.allego.DSPParams\x12)\n\x0esoftwareStage1\x18\x02 \x03(\x0b\x32\x11.allego.DSPParams\x12)\n\x0esoftwareStage2\x18\x03 \x03(\x0b\x32\x11.allego.DSPParams\x12&\n\x0bspikeSorter\x18\x04 \x03(\x0b\x32\x11.allego.DSPParams\"\xb2\x01\n\x10SetSensorRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x1a\n\x04port\x18\x02 \x02(\x0e\x32\x0c.allego.Port\x12\x0f\n\x07probeId\x18\x03 \x01(\t\x12\x13\n\x0bheadstageId\x18\x04 \x01(\t\x12\x18\n\x10\x63onnectionNtvIdx\x18\x05 \x01(\x05\x12\x13\n\x0bnumChannels\x18\x06 \x01(\x05\x12\x16\n\x0euseLocalDevice\x18\x07 \x01(\x08\"m\n\x11SensorPositionTcs\x12\t\n\x01X\x18\x02 \x02(\x01\x12\t\n\x01Y\x18\x03 \x02(\x01\x12\t\n\x01Z\x18\x04 \x02(\x01\x12\x11\n\tRingAngle\x18\x05 \x02(\x01\x12\x12\n\nAxialAngle\x18\x06 \x02(\x01\x12\x10\n\x08\x41rcAngle\x18\x07 \x02(\x01\"\x90\x01\n\x1bSetSensorPositionTcsRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x1a\n\x04port\x18\x02 \x02(\x0e\x32\x0c.allego.Port\x12+\n\x08position\x18\x03 \x02(\x0b\x32\x19.allego.SensorPositionTcs\x12\x11\n\tsensorIdx\x18\x04 \x01(\x05\"F\n\x0fSitePositionTcs\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12\t\n\x01X\x18\x02 \x02(\x01\x12\t\n\x01Y\x18\x03 \x02(\x01\x12\t\n\x01Z\x18\x04 \x02(\x01\"\x7f\n\x1aSetSitePositionsTcsRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x1a\n\x04port\x18\x02 \x02(\x0e\x32\x0c.allego.Port\x12.\n\rsitePositions\x18\x03 \x03(\x0b\x32\x17.allego.SitePositionTcs\"Y\n\x17\x46\x65\x61tureStartStopRequest\x12\x0e\n\x06nodeId\x18\x01 \x02(\t\x12.\n\x0e\x66\x65\x61tureLicense\x18\x02 \x02(\x0e\x32\x16.allego.FeatureLicense\"!\n\x0cPrivacyReply\x12\x11\n\tisPrivate\x18\x02 \x02(\x08\"&\n\x11SetPrivacyRequest\x12\x11\n\tisPrivate\x18\x01 \x02(\x08\"7\n\x0b\x44\x65nseMatrix\x12\x0c\n\x04rows\x18\x01 \x02(\x03\x12\x0c\n\x04\x63ols\x18\x02 \x02(\x03\x12\x0c\n\x04\x64\x61ta\x18\x03 \x02(\x0c\"\\\n\tHistogram\x12\r\n\x05stats\x18\x01 \x03(\x01\x12\x0e\n\x06\x63ounts\x18\x02 \x03(\x01\x12\x10\n\x08\x64ividers\x18\x03 \x03(\x01\x12\x0f\n\x07numBins\x18\x04 \x02(\x03\x12\r\n\x05isPDF\x18\x05 \x02(\x08\"Y\n\x0bKpiMetricID\x12$\n\x04mode\x18\x01 \x02(\x0e\x32\x16.allego.KpiMetricsMode\x12$\n\x04name\x18\x02 \x02(\x0e\x32\x16.allego.KpiMetricsEnum\"\x85\x01\n\tTimeRange\x12\x14\n\x0ctimeRangeSec\x18\x01 \x03(\x01\x12\x11\n\ttimestamp\x18\x02 \x03(\x03\x12\n\n\x02\x66s\x18\x03 \x02(\x01\x12\x15\n\rwallTimeStart\x18\x04 \x01(\t\x12,\n\x08wallTime\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"a\n\tBundleReq\x12\x0f\n\x07ntvIdxs\x18\x01 \x03(\x05\x12\x1d\n\x02tR\x18\x02 \x02(\x0b\x32\x11.allego.TimeRange\x12$\n\x07metrics\x18\x04 \x03(\x0b\x32\x13.allego.KpiMetricID\"i\n\rKpiMetricsReq\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12!\n\x05stype\x18\x02 \x01(\x0e\x32\x12.allego.SignalType\x12\x1e\n\x03\x61rg\x18\x03 \x02(\x0b\x32\x11.allego.BundleReq\"\xe8\x02\n\x0eKpiMetricsData\x12\x12\n\nnumPackets\x18\x01 \x02(\x03\x12\x0f\n\x07numSigs\x18\x02 \x02(\x03\x12\x12\n\nnumMetrics\x18\x03 \x02(\x03\x12#\n\x06metric\x18\x04 \x03(\x0b\x32\x13.allego.KpiMetricID\x12\x0f\n\x07pktIdxs\x18\x05 \x03(\x03\x12\x36\n\nstatsChans\x18\x07 \x02(\x0b\x32\".allego.KpiMetricsData.MetricStats\x12\x37\n\x0bstatsGlobal\x18\x08 \x02(\x0b\x32\".allego.KpiMetricsData.MetricStats\x12\x14\n\x0cpacketDurSec\x18\t \x02(\x01\x12\x1d\n\x02tR\x18\n \x02(\x0b\x32\x11.allego.TimeRange\x1a\x41\n\x0bMetricStats\x12\x0c\n\x04mean\x18\x01 \x03(\x01\x12\n\n\x02sD\x18\x02 \x03(\x01\x12\x0b\n\x03max\x18\x03 \x03(\x01\x12\x0b\n\x03min\x18\x04 \x03(\x01\"w\n\x16KpiBundlePacketMetrics\x12\x0f\n\x07ntvIdxs\x18\x01 \x03(\x05\x12#\n\x07sigType\x18\x02 \x02(\x0e\x32\x12.allego.SignalType\x12\'\n\x07metrics\x18\x04 \x02(\x0b\x32\x16.allego.KpiMetricsData\"S\n\nKpiMetrics\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12.\n\x06\x62undle\x18\x02 \x02(\x0b\x32\x1e.allego.KpiBundlePacketMetrics\"\xbe\x01\n\x18SignalMetricsPacketReply\x12\x0f\n\x07ntvIdxs\x18\x01 \x03(\x05\x12#\n\x07sigType\x18\x02 \x02(\x0e\x32\x12.allego.SignalType\x12$\n\x07metrics\x18\x03 \x03(\x0b\x32\x13.allego.KpiMetricID\x12\'\n\nmetricVals\x18\x04 \x02(\x0b\x32\x13.allego.DenseMatrix\x12\x1d\n\x02tR\x18\x05 \x02(\x0b\x32\x11.allego.TimeRange\"c\n\x11KpiControlRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12!\n\x05stype\x18\x02 \x01(\x0e\x32\x12.allego.SignalType\x12\x14\n\x0cisAllBundles\x18\x03 \x01(\x08\":\n\x12SetKpiParamRequest\x12\x15\n\rstreamGroupId\x18\x01 \x01(\t\x12\r\n\x05param\x18\x02 \x01(\x01\",\n\x13GetKpiStatusRequest\x12\x15\n\rstreamGroupId\x18\x02 \x02(\t\"\'\n\x12KpiStandardRequest\x12\x11\n\tdsourceID\x18\x02 \x03(\t\"\xba\x01\n\rKpiFileStatus\x12,\n\x07\x64source\x18\x01 \x03(\x0b\x32\x1b.allego.KpiFileStatus.State\x1a{\n\x05State\x12\x0f\n\x07isAvail\x18\x01 \x02(\x08\x12\x12\n\nisComplete\x18\x02 \x01(\x08\x12\x12\n\ndsourceUID\x18\x03 \x01(\t\x12 \n\x05kpiTR\x18\x04 \x01(\x0b\x32\x11.allego.TimeRange\x12\x17\n\x0f\x66ilePathAndName\x18\x05 \x01(\t\"\xda\x05\n\x0eKpiFileStatus2\x12>\n\x07\x64source\x18\x01 \x03(\x0b\x32-.allego.KpiFileStatus2.KpiDatasourceStateSpec\x1a\xfc\x02\n\tKPI_State\x12\x0f\n\x07isAvail\x18\x01 \x02(\x08\x12\x12\n\nisComplete\x18\x02 \x01(\x08\x12\x14\n\x0c\x66racComplete\x18\x03 \x01(\x01\x12\x17\n\x0f\x66ilePathAndName\x18\x04 \x01(\t\x12 \n\x05kpiTR\x18\x05 \x01(\x0b\x32\x11.allego.TimeRange\x12\x14\n\x0cpacketDurSec\x18\x06 \x01(\x01\x12\x0e\n\x06numAmp\x18\x07 \x01(\x03\x12\x18\n\x10\x62ytesInBundlePkt\x18\x08 \x01(\x03\x12\x12\n\nnumPackets\x18\t \x01(\x03\x12\x12\n\ndatasetUID\x18\n \x01(\t\x12\x17\n\x0fupdatePeriodSec\x18\x0b \x01(\x01\x12\x16\n\x0epersistenceSec\x18\x0c \x01(\x01\x12\x18\n\x10numPacketsMemory\x18\r \x01(\x03\x12\x13\n\x0bmemoryBytes\x18\x0e \x01(\x01\x12\n\n\x02\x66s\x18\x0f \x01(\x01\x12\x17\n\x0fisTrackingCache\x18\x10 \x01(\x08\x12\x0c\n\x04\x62\x65ta\x18\x11 \x01(\x01\x1aq\n\x10\x44\x61tasource_State\x12\x17\n\x0f\x66ilePathAndName\x18\x01 \x01(\t\x12\x1d\n\x02TR\x18\x02 \x01(\x0b\x32\x11.allego.TimeRange\x12\x12\n\ndatasetUID\x18\x03 \x01(\t\x12\x11\n\tdsourceID\x18\x04 \x01(\t\x1a\x95\x01\n\x16KpiDatasourceStateSpec\x12\x37\n\x06source\x18\x01 \x02(\x0b\x32\'.allego.KpiFileStatus2.Datasource_State\x12-\n\x03kpi\x18\x02 \x02(\x0b\x32 .allego.KpiFileStatus2.KPI_State\x12\x13\n\x0bisSprinting\x18\x03 \x01(\x08\"\x93\x02\n\x0fKpiFileMetadata\x12.\n\x07\x64source\x18\x01 \x03(\x0b\x32\x1d.allego.KpiFileMetadata.State\x1a\xcf\x01\n\x05State\x12\x0f\n\x07isAvail\x18\x01 \x02(\x08\x12\x12\n\ndsourceUID\x18\x02 \x01(\t\x12\x11\n\tpacketDur\x18\x03 \x01(\x01\x12\x0c\n\x04nAMP\x18\x04 \x01(\x03\x12\x1b\n\x13\x62ytesInBundlePacket\x18\x05 \x01(\x03\x12\x12\n\nnumPackets\x18\x06 \x01(\x03\x12 \n\x05kpiTR\x18\x07 \x01(\x0b\x32\x11.allego.TimeRange\x12\x17\n\x0f\x66ilePathAndName\x18\x08 \x01(\t\x12\x14\n\x0c\x66racComplete\x18\t \x01(\x01\"\xd3\x02\n\x0eKpiStatusReply\x12\x15\n\rstreamGroupId\x18\x02 \x02(\t\x12\x11\n\ttimeRange\x18\x03 \x01(\x01\x12\x16\n\x0etimestampRange\x18\x04 \x01(\x03\x12\x18\n\x10numPacketsMemory\x18\x05 \x02(\x03\x12\x11\n\tpacketDur\x18\x06 \x02(\x01\x12\x14\n\x0cupdatePeriod\x18\x07 \x02(\x01\x12\x13\n\x0bpersistence\x18\x08 \x02(\x01\x12\x0c\n\x04\x62\x65ta\x18\t \x02(\x01\x12\x1d\n\x15isTrackingSignalCache\x18\x0b \x02(\x08\x12\x12\n\nnumPackets\x18\x0c \x02(\x03\x12\x13\n\x0bmemoryBytes\x18\r \x02(\x01\x12\n\n\x02\x66s\x18\x0e \x01(\x01\x12\x15\n\rwallTimeStart\x18\x0f \x01(\t\x12\x1d\n\x02tR\x18\x10 \x01(\x0b\x32\x11.allego.TimeRange\x12\x0f\n\x07numSigs\x18\x11 \x01(\x03\"\xe6\x02\n\x11SigKpiParamRecord\x12\x15\n\risEventDetect\x18\x01 \x02(\x08\x12\x12\n\nntvChanIdx\x18\x02 \x02(\x05\x12\x11\n\teventThr0\x18\x03 \x02(\x01\x12\x11\n\teventThr1\x18\x04 \x02(\x01\x12\x13\n\x0b\x65ventThrSd0\x18\x05 \x02(\x01\x12\x13\n\x0b\x65ventThrSd1\x18\x06 \x02(\x01\x12\x11\n\tpreThrPts\x18\x07 \x02(\x05\x12\x12\n\npostThrPts\x18\x08 \x02(\x05\x12\x11\n\tevtDurPts\x18\t \x02(\x05\x12\x11\n\tshadowPts\x18\n \x02(\x05\x12\x0e\n\x06preThr\x18\x0b \x02(\x01\x12\x0f\n\x07postThr\x18\x0c \x02(\x01\x12\x0e\n\x06\x65vtDur\x18\r \x02(\x01\x12\x0e\n\x06shadow\x18\x0e \x02(\x01\x12\x11\n\tisSetThr0\x18\x0f \x02(\x08\x12\x11\n\tisSetThr1\x18\x10 \x02(\x08\x12\x10\n\x08isSDThr0\x18\x11 \x02(\x08\x12\x10\n\x08isSDThr1\x18\x12 \x02(\x08\"J\n\x0e\x41nnotateBundle\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\r\n\x05notes\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x01(\t\"]\n\x0fProjectMetadata\x12\x12\n\nprojectUID\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61seUID\x18\x02 \x01(\t\x12\x10\n\x08trialUID\x18\x03 \x01(\t\x12\x13\n\x0b\x61nnotateUID\x18\x04 \x03(\t\"3\n\x16SensorExtendedMetadata\x12\x19\n\x11sensorInstanceUID\x18\x01 \x01(\t\"%\n\x0fGonumMatrixList\x12\x12\n\nmdataBytes\x18\x01 \x02(\x0c\"6\n\x0fRadixMatrixList\x12#\n\x06matrix\x18\x01 \x03(\x0b\x32\x13.allego.RadixMatrix\"*\n\x0bRadixMatrix\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x02\x12\r\n\x05shape\x18\x02 \x03(\x05\"/\n\x10RadixMatrixBytes\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\x12\r\n\x05shape\x18\x02 \x03(\x05\"8\n\x10RadixSignalsList\x12$\n\x06matrix\x18\x01 \x03(\x0b\x32\x14.allego.RadixSignals\"\xa9\x01\n\x0cRadixSignals\x12\x10\n\x08sampFreq\x18\x01 \x02(\x01\x12 \n\x03pri\x18\x02 \x02(\x0b\x32\x13.allego.RadixMatrix\x12 \n\x03\x61ux\x18\x03 \x02(\x0b\x32\x13.allego.RadixMatrix\x12 \n\x03\x64in\x18\x04 \x02(\x0b\x32\x13.allego.RadixMatrix\x12!\n\x04\x64out\x18\x05 \x02(\x0b\x32\x13.allego.RadixMatrix\"\x19\n\x0cVectorString\x12\t\n\x01x\x18\x01 \x03(\t\"\x1a\n\rVectorFloat64\x12\t\n\x01x\x18\x01 \x03(\x01\"G\n\x12VectorSliceFloat64\x12\"\n\x03vec\x18\x01 \x03(\x0b\x32\x15.allego.VectorFloat64\x12\r\n\x05label\x18\x02 \x01(\t\"\xde\x02\n\x14LogsysKpiStatusReply\x12\x1f\n\x05portA\x18\x01 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portB\x18\x02 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portC\x18\x03 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portD\x18\x04 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portE\x18\x05 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portF\x18\x06 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portG\x18\x07 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portH\x18\x08 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1e\n\x04\x61ux0\x18\t \x02(\x0b\x32\x10.allego.KpiCache\x12\x1e\n\x04\x61ux1\x18\n \x02(\x0b\x32\x10.allego.KpiCache\"\xfc\x02\n\x08KpiCache\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x12\n\npersistDur\x18\x03 \x02(\x01\x12\x15\n\rminNumPackets\x18\x04 \x02(\x05\x12\x11\n\tsizeBytes\x18\x05 \x02(\x05\x12\x12\n\nnumPackets\x18\x06 \x02(\x05\x12\x0e\n\x06tRange\x18\x07 \x03(\x01\x12\x0f\n\x07tsRange\x18\x08 \x03(\x03\x12\x15\n\rmeanPacketDur\x18\t \x02(\x01\x12\x19\n\x11meanCalcPacketDur\x18\n \x02(\x01\x12\x11\n\tpacketDur\x18\x0b \x02(\x01\x12\x1d\n\x15totalPacketsProcessed\x18\x0c \x02(\r\x12\x12\n\nsignalType\x18\r \x02(\t\x12\x12\n\nnumPriSigs\x18\x0e \x02(\x05\x12\x12\n\nnumAuxSigs\x18\x0f \x02(\x05\x12\x12\n\nnumDinSigs\x18\x10 \x02(\x05\x12\x13\n\x0bnumDoutSigs\x18\x11 \x02(\x05\x12\x14\n\x0cupdatePeriod\x18\x12 \x02(\x01\"\xfa\x02\n\x12LogsysKpiTailReply\x12\"\n\x05portA\x18\x01 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portB\x18\x02 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portC\x18\x03 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portD\x18\x04 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portE\x18\x05 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portF\x18\x06 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portG\x18\x07 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portH\x18\x08 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12!\n\x04\x61ux0\x18\t \x01(\x0b\x32\x13.allego.KpiPortInfo\x12!\n\x04\x61ux1\x18\n \x01(\x0b\x32\x13.allego.KpiPortInfo\"3\n\x0bKpiPortInfo\x12$\n\x07kpiTail\x18\x01 \x03(\x0b\x32\x13.allego.KpiTailRows\"\xf4\x02\n\x0bKpiTailRows\x12\x10\n\x08wallTime\x18\x01 \x02(\t\x12\x11\n\ttimeRange\x18\x02 \x02(\x01\x12\x14\n\x0clocalSigType\x18\x03 \x02(\t\x12\x12\n\nntvChanIdx\x18\x04 \x02(\x03\x12\x0b\n\x03\x64ur\x18\x05 \x02(\x01\x12\x0e\n\x06stdDev\x18\x06 \x02(\x01\x12\x0f\n\x07\x63StdDev\x18\x07 \x02(\x01\x12\x11\n\tabsEvtAmp\x18\x08 \x02(\x01\x12\x12\n\ncabsEvtAmp\x18\t \x02(\x01\x12\x0b\n\x03SNR\x18\n \x02(\x01\x12\x0c\n\x04\x63SNR\x18\x0b \x02(\x01\x12\x0f\n\x07numEvts\x18\x0c \x02(\x05\x12\x10\n\x08\x63numEvts\x18\r \x02(\x05\x12\x0f\n\x07\x65vtRate\x18\x0e \x02(\x01\x12\x10\n\x08\x63\x45vtRate\x18\x0f \x02(\x01\x12\x0b\n\x03max\x18\x10 \x02(\x01\x12\x0c\n\x04\x63max\x18\x11 \x02(\x01\x12\x0b\n\x03min\x18\x12 \x02(\x01\x12\x0c\n\x04\x63min\x18\x13 \x02(\x01\x12\x14\n\x0cmeanPosPkAmp\x18\x14 \x02(\x01\x12\x14\n\x0cmeanNegPkAmp\x18\x15 \x02(\x01\"*\n\x18WarehouseHealthcheckSpec\x12\x0e\n\x06\x65rrMsg\x18\x01 \x01(\t\"(\n\x19OutfitterGetDeviceRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x9e\x01\n\x11SensorCompRequest\x12 \n\x05probe\x18\x01 \x03(\x0b\x32\x11.allego.ProbeDesc\x12(\n\theadstage\x18\x02 \x03(\x0b\x32\x15.allego.HeadstageDesc\x12\x16\n\x0eisIncludeModel\x18\x03 \x01(\x08\x12\x19\n\x11isIncludeMetadata\x18\x04 \x01(\x08\x12\n\n\x02iD\x18\x05 \x01(\t\"z\n\x19RegisterSensorCompRequest\x12 \n\x05probe\x18\x01 \x03(\x0b\x32\x11.allego.ProbeDesc\x12(\n\theadstage\x18\x02 \x03(\x0b\x32\x15.allego.HeadstageDesc\x12\x11\n\tprofileID\x18\x03 \x02(\t\"\x92\x01\n\x1dSaveSensorCompInstanceRequest\x12 \n\x05probe\x18\x01 \x01(\x0b\x32\x11.allego.ProbeDesc\x12(\n\theadstage\x18\x02 \x01(\x0b\x32\x15.allego.HeadstageDesc\x12\x19\n\x11isIncludeMetadata\x18\x04 \x01(\x08\x12\n\n\x02iD\x18\x05 \x01(\t\"&\n\tProbeDesc\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0b\n\x03uID\x18\x02 \x01(\t\"*\n\rHeadstageDesc\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0b\n\x03uID\x18\x02 \x01(\t\"`\n\x12GetSensorCompReply\x12 \n\x05probe\x18\x01 \x03(\x0b\x32\x11.allego.ProbeSpec\x12(\n\theadstage\x18\x02 \x03(\x0b\x32\x15.allego.HeadstageSpec\"x\n\tProbeSpec\x12\x1f\n\x04\x64\x65sc\x18\x01 \x02(\x0b\x32\x11.allego.ProbeDesc\x12!\n\x05model\x18\x02 \x01(\x0b\x32\x12.allego.ProbeModel\x12\'\n\x08metaData\x18\x03 \x01(\x0b\x32\x15.allego.ProbeMetaData\"\x88\x01\n\rHeadstageSpec\x12#\n\x04\x64\x65sc\x18\x01 \x02(\x0b\x32\x15.allego.HeadstageDesc\x12%\n\x05model\x18\x02 \x01(\x0b\x32\x16.allego.HeadstageModel\x12+\n\x08metaData\x18\x03 \x01(\x0b\x32\x19.allego.HeadstageMetaData\"\xce\x04\n\nProbeModel\x12\n\n\x02iD\x18\x01 \x02(\t\x12.\n\x04site\x18\x02 \x03(\x0b\x32 .allego.ProbeModel.ProbeSiteDesc\x12\x34\n\twireframe\x18\x03 \x02(\x0b\x32!.allego.ProbeModel.ProbeWireFrame\x12\x34\n\x0esiteOverallMin\x18\x05 \x02(\x0b\x32\x1c.allego.ProbeModel.ProbePtXY\x12\x34\n\x0esiteOverallMax\x18\x06 \x02(\x0b\x32\x1c.allego.ProbeModel.ProbePtXY\x1a\xde\x01\n\rProbeSiteDesc\x12\x0c\n\x04\x61rea\x18\x01 \x02(\x01\x12\x0f\n\x07\x63\x65nterX\x18\x02 \x02(\x01\x12\x0f\n\x07\x63\x65nterY\x18\x03 \x02(\x01\x12\x0f\n\x07\x63\x65nterZ\x18\x04 \x02(\x01\x12\x11\n\tlimitXMax\x18\x05 \x02(\x01\x12\x11\n\tlimitXMin\x18\x06 \x02(\x01\x12\x11\n\tlimitYMax\x18\x07 \x02(\x01\x12\x11\n\tlimitYMin\x18\x08 \x02(\x01\x12\x11\n\tlimitZMax\x18\t \x02(\x01\x12\x11\n\tlimitZMin\x18\n \x02(\x01\x12\x0b\n\x03num\x18\x0b \x02(\x03\x12\r\n\x05shape\x18\x0c \x02(\t\x1a^\n\x0eProbeWireFrame\x12,\n\x06vertex\x18\x01 \x03(\x0b\x32\x1c.allego.ProbeModel.ProbePtXY\x12\x0e\n\x06limitX\x18\x02 \x03(\x01\x12\x0e\n\x06limitY\x18\x03 \x03(\x01\x1a!\n\tProbePtXY\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\"_\n\rProbeMetaData\x12\x11\n\tprobeName\x18\x01 \x02(\t\x12\x10\n\x08numSites\x18\x02 \x02(\x05\x12\x13\n\x0b\x63\x61talogTags\x18\x03 \x02(\t\x12\x14\n\x0cinstanceTags\x18\x04 \x02(\t\"\x84\x01\n\x0eHeadstageModel\x12\n\n\x02iD\x18\x01 \x02(\t\x12\x31\n\x04rows\x18\x02 \x03(\x0b\x32#.allego.HeadstageModel.HeadstageRow\x1a\x33\n\x0cHeadstageRow\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x03\x12\x0f\n\x07siteNum\x18\x02 \x02(\x03\"\x13\n\x11HeadstageMetaData\"5\n\x0bUserProfile\x12\x11\n\tprofileID\x18\x01 \x02(\t\x12\x13\n\x0blicenseCode\x18\x02 \x02(\t\"B\n\x16GetCurrentProfileReply\x12(\n\x0buserProfile\x18\x01 \x02(\x0b\x32\x13.allego.UserProfile\"@\n\x13GetAllProfilesReply\x12)\n\x0cuserProfiles\x18\x01 \x03(\x0b\x32\x13.allego.UserProfile\"-\n\x18SetCurrentProfileRequest\x12\x11\n\tprofileID\x18\x01 \x02(\t\"\x88\x01\n\x14ManageNodeOrgPayload\x12\r\n\x05orgID\x18\x01 \x01(\t\x12\x0f\n\x07orgName\x18\x02 \x01(\t\x12\x14\n\x0corgShortName\x18\x03 \x01(\t\x12\x0c\n\x04\x63ity\x18\x04 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x0c\n\x04tags\x18\x07 \x01(\t\"i\n\x14ManageNodeOrgRequest\x12\"\n\x03\x63md\x18\x01 \x02(\x0e\x32\x15.allego.ManageNodeCmd\x12-\n\x07payload\x18\x02 \x03(\x0b\x32\x1c.allego.ManageNodeOrgPayload\"S\n\x12ManageNodeOrgReply\x12-\n\x07payload\x18\x01 \x03(\x0b\x32\x1c.allego.ManageNodeOrgPayload\x12\x0e\n\x06\x65rrMsg\x18\x02 \x01(\t\"\xa2\x01\n\x14ManageNodeLabPayload\x12\r\n\x05labID\x18\x01 \x01(\t\x12\x0f\n\x07labDesc\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65pt\x18\x03 \x01(\t\x12\x14\n\x0corganization\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x64minID\x18\x05 \x01(\t\x12\x11\n\tlabHeadID\x18\x06 \x01(\t\x12\x14\n\x0clabManagerID\x18\x07 \x01(\t\x12\x0c\n\x04tags\x18\x08 \x01(\t\"i\n\x14ManageNodeLabRequest\x12\"\n\x03\x63md\x18\x01 \x02(\x0e\x32\x15.allego.ManageNodeCmd\x12-\n\x07payload\x18\x02 \x03(\x0b\x32\x1c.allego.ManageNodeLabPayload\"S\n\x12ManageNodeLabReply\x12-\n\x07payload\x18\x01 \x03(\x0b\x32\x1c.allego.ManageNodeLabPayload\x12\x0e\n\x06\x65rrMsg\x18\x02 \x01(\t\"\x99\x01\n\x15ManageNodeUserPayload\x12\x0e\n\x06userID\x18\x01 \x01(\t\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\x0c\x12\"\n\x04role\x18\x04 \x01(\x0e\x32\x14.allego.UserRoleType\x12\r\n\x05\x65mail\x18\x05 \x01(\t\x12\x0f\n\x07labName\x18\x06 \x01(\t\x12\x0c\n\x04tags\x18\x07 \x01(\t\"k\n\x15ManageNodeUserRequest\x12\"\n\x03\x63md\x18\x01 \x02(\x0e\x32\x15.allego.ManageNodeCmd\x12.\n\x07payload\x18\x02 \x03(\x0b\x32\x1d.allego.ManageNodeUserPayload\"U\n\x13ManageNodeUserReply\x12.\n\x07payload\x18\x01 \x03(\x0b\x32\x1d.allego.ManageNodeUserPayload\x12\x0e\n\x06\x65rrMsg\x18\x02 \x01(\t\"6\n\x13\x43\x61talogProbePayload\x12\x1f\n\x04spec\x18\x01 \x02(\x0b\x32\x11.allego.ProbeSpec\"]\n\x10ProbeNodeRequest\x12\"\n\x03\x63md\x18\x01 \x02(\x0e\x32\x15.allego.ManageNodeCmd\x12%\n\x07payload\x18\x02 \x03(\x0b\x32\x14.allego.ProbePayload\"7\n\x0eProbeNodeReply\x12%\n\x07payload\x18\x01 \x03(\x0b\x32\x14.allego.ProbePayload\"/\n\x0cProbePayload\x12\x1f\n\x04spec\x18\x01 \x02(\x0b\x32\x11.allego.ProbeSpec\"\xa5\x02\n\x0b\x45\x64gePayload\x12/\n\x06source\x18\x01 \x02(\x0b\x32\x1f.allego.EdgePayload.GenericNode\x12/\n\x06target\x18\x02 \x02(\x0b\x32\x1f.allego.EdgePayload.GenericNode\x12)\n\tedgeLabel\x18\x03 \x02(\x0e\x32\x16.allego.WorldEdgeLabel\x12-\n\tdirection\x18\x04 \x02(\x0e\x32\x1a.allego.WorldEdgeDirection\x1aZ\n\x0bGenericNode\x12%\n\x05label\x18\x01 \x02(\x0e\x32\x16.allego.WorldNodeLabel\x12\x11\n\tidPropKey\x18\x02 \x02(\t\x12\x11\n\tidPropVal\x18\x03 \x02(\t\"8\n\x10WorldEdgeRequest\x12$\n\x07payload\x18\x01 \x03(\x0b\x32\x13.allego.EdgePayload\"\x10\n\x0eWorldEdgeReply\"E\n\x11QueryWorldRequest\x12\"\n\x03\x63md\x18\x01 \x02(\x0e\x32\x15.allego.WorldQueryCmd\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\"\xe6\x01\n\rQueryWorldRec\x12)\n\x03org\x18\x01 \x01(\x0b\x32\x1c.allego.ManageNodeOrgPayload\x12)\n\x03lab\x18\x02 \x01(\x0b\x32\x1c.allego.ManageNodeLabPayload\x12+\n\x04user\x18\x03 \x01(\x0b\x32\x1d.allego.ManageNodeUserPayload\x12-\n\x08\x63\x61tProbe\x18\x04 \x01(\x0b\x32\x1b.allego.CatalogProbePayload\x12#\n\x05probe\x18\x05 \x01(\x0b\x32\x14.allego.ProbePayload\"9\n\x0fQueryWorldReply\x12&\n\x07payload\x18\x01 \x03(\x0b\x32\x15.allego.QueryWorldRec\">\n\x1aHighLowPassTransformParams\x12\x11\n\tfrequency\x18\x01 \x02(\x01\x12\r\n\x05order\x18\x02 \x01(\x05\"Q\n\x13\x42\x61ndTransformParams\x12\x14\n\x0clowFrequency\x18\x01 \x02(\x01\x12\x15\n\rhighFrequency\x18\x02 \x02(\x01\x12\r\n\x05order\x18\x03 \x01(\x05\"U\n\x14NotchTransformParams\x12\x16\n\x0enotchFrequency\x18\x01 \x02(\x01\x12\x16\n\x0enotchBandwidth\x18\x02 \x02(\x01\x12\r\n\x05order\x18\x03 \x01(\x05\"\x14\n\x12\x43\x41RTransformParams\"2\n\x19VirtualRefTransformParams\x12\x15\n\rrefNtvChanIdx\x18\x01 \x02(\x05\"K\n\x18PairedRefTransformParams\x12\x15\n\rrefNtvChanIdx\x18\x01 \x02(\x05\x12\x18\n\x10targetNtvChanIdx\x18\x02 \x02(\x05\"u\n\x1d\x44\x61taSourceSinkTransformParams\x12\x10\n\x08\x64srcName\x18\x01 \x02(\t\x12\x0c\n\x04path\x18\x02 \x02(\t\x12(\n\x08\x66ileType\x18\x03 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12\n\n\x02id\x18\x04 \x01(\t\"Y\n\x1d\x42ulkDataSourceTransformParams\x12\x38\n\tsrcParams\x18\x01 \x03(\x0b\x32%.allego.DataSourceSinkTransformParams\"e\n\x1b\x42ulkDataSinkTransformParams\x12\x0e\n\x06suffix\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x02(\t\x12(\n\x08\x66ileType\x18\x03 \x02(\x0e\x32\x16.allego.RadixFileTypes\">\n\x18SliceTimeTransformParams\x12\x11\n\ttimeStart\x18\x01 \x02(\x01\x12\x0f\n\x07timeEnd\x18\x02 \x02(\x01\"n\n\x1cSliceChannelsTransformParams\x12\x13\n\x0bsysChanIdxs\x18\x01 \x03(\x05\x12(\n\x0bsignalGroup\x18\x02 \x01(\x0b\x32\x13.allego.SignalGroup\x12\x0f\n\x07\x64srcUid\x18\x03 \x01(\t\"1\n\x19\x44ownsampleTransformParams\x12\x14\n\x0csampleFactor\x18\x01 \x02(\x05\"\xec\x01\n\x1aRemapSensorTransformParams\x12>\n\x07sensors\x18\x01 \x03(\x0b\x32-.allego.RemapSensorTransformParams.SensorSpec\x12\x0f\n\x07\x64srcUid\x18\x03 \x01(\t\x1a}\n\nSensorSpec\x12\x1a\n\x04port\x18\x02 \x02(\x0e\x32\x0c.allego.Port\x12\x0f\n\x07probeId\x18\x03 \x02(\t\x12\x13\n\x0bheadstageId\x18\x04 \x02(\t\x12\x18\n\x10\x63onnectionNtvIdx\x18\x05 \x01(\x05\x12\x13\n\x0bnumChannels\x18\x06 \x01(\x05\" \n\x08Position\x12\t\n\x01x\x18\x01 \x02(\x05\x12\t\n\x01y\x18\x02 \x02(\x05\"\xb0\x07\n\rTransformNode\x12\n\n\x02id\x18\x01 \x02(\t\x12\'\n\x04type\x18\x02 \x02(\x0e\x32\x19.allego.TransformNodeType\x12\"\n\x08position\x18\x03 \x01(\x0b\x32\x10.allego.Position\x12\x0f\n\x07invalid\x18\x04 \x02(\x08\x12\x14\n\x0c\x65rrorMessage\x18\x05 \x01(\t\x12=\n\x11highLowPassParams\x18\x06 \x01(\x0b\x32\".allego.HighLowPassTransformParams\x12/\n\nbandParams\x18\x07 \x01(\x0b\x32\x1b.allego.BandTransformParams\x12\x31\n\x0bnotchParams\x18\x08 \x01(\x0b\x32\x1c.allego.NotchTransformParams\x12-\n\tcarParams\x18\t \x01(\x0b\x32\x1a.allego.CARTransformParams\x12;\n\x10virtualRefParams\x18\n \x01(\x0b\x32!.allego.VirtualRefTransformParams\x12\x39\n\x0fpairedRefParams\x18\x0b \x01(\x0b\x32 .allego.PairedRefTransformParams\x12\x43\n\x14\x64\x61tasourceSinkParams\x18\x0c \x01(\x0b\x32%.allego.DataSourceSinkTransformParams\x12\x39\n\x0fsliceTimeParams\x18\r \x01(\x0b\x32 .allego.SliceTimeTransformParams\x12\x41\n\x13sliceChannelsParams\x18\x0e \x01(\x0b\x32$.allego.SliceChannelsTransformParams\x12;\n\x10\x64ownsampleParams\x18\x0f \x01(\x0b\x32!.allego.DownsampleTransformParams\x12=\n\x11remapSensorParams\x18\x10 \x01(\x0b\x32\".allego.RemapSensorTransformParams\x12\x43\n\x14\x62ulkDataSourceParams\x18\x11 \x01(\x0b\x32%.allego.BulkDataSourceTransformParams\x12?\n\x12\x62ulkDataSinkParams\x18\x12 \x01(\x0b\x32#.allego.BulkDataSinkTransformParams\x12\x10\n\x08selected\x18\x13 \x01(\x08\"M\n\rTransformEdge\x12\n\n\x02id\x18\x01 \x02(\t\x12\x0e\n\x06source\x18\x02 \x02(\t\x12\x0e\n\x06target\x18\x03 \x02(\t\x12\x10\n\x08selected\x18\x04 \x01(\x08\"t\n\x08Protocol\x12\n\n\x02id\x18\x01 \x02(\t\x12-\n\x0etransformNodes\x18\x02 \x03(\x0b\x32\x15.allego.TransformNode\x12-\n\x0etransformEdges\x18\x03 \x03(\x0b\x32\x15.allego.TransformEdge\"%\n\x0fProtocolRequest\x12\x12\n\nprotocolID\x18\x01 \x02(\t\"B\n\x15RenameProtocolRequest\x12\x12\n\nprotocolID\x18\x01 \x02(\t\x12\x15\n\rnewProtocolID\x18\x02 \x02(\t\";\n\x14GetAllProtocolsReply\x12#\n\tprotocols\x18\x01 \x03(\x0b\x32\x10.allego.Protocol\"\x8f\x01\n\x15\x41pplyProtocolProgress\x12\x1c\n\x14lastTimestampWritten\x18\x01 \x02(\x05\x12\x18\n\x10\x64srcTimestampEnd\x18\x02 \x02(\x05\x12\x14\n\x0c\x66racComplete\x18\x03 \x01(\x01\x12\x14\n\x0cincrementSec\x18\x04 \x01(\x01\x12\x12\n\nprotocolID\x18\x05 \x02(\t\"\x9a\x01\n\x1aSpikeSorterSetParamRequest\x12\x15\n\rspikeSorterID\x18\x01 \x02(\t\x12,\n\x03\x63md\x18\x02 \x02(\x0e\x32\x1f.allego.SpikeSorterParamCommand\x12\x12\n\nregFloat64\x18\x03 \x03(\x01\x12\x0f\n\x07regBool\x18\x05 \x03(\x08\x12\x12\n\nntvChanIdx\x18\x06 \x03(\x05\"Q\n\x1bSpikeSorterSetParamsRequest\x12\x32\n\x06params\x18\x01 \x03(\x0b\x32\".allego.SpikeSorterSetParamRequest\"\xa7\x02\n\x1dSpikeSorterParamCommandRecord\x12\x11\n\tisEnabled\x18\x01 \x02(\x08\x12\x12\n\nntvChanIdx\x18\x02 \x02(\x05\x12\x0b\n\x03thr\x18\x03 \x03(\x01\x12\r\n\x05thrSd\x18\x04 \x03(\x01\x12\x11\n\tthrWdwPts\x18\x05 \x03(\x05\x12\x0e\n\x06thrWdw\x18\x06 \x03(\x01\x12\x0e\n\x06shadow\x18\x07 \x02(\x01\x12\x11\n\tshadowPts\x18\x08 \x02(\x05\x12\x10\n\x08isSetThr\x18\t \x03(\x08\x12\x0f\n\x07weakThr\x18\n \x03(\x01\x12\x11\n\tweakThrSd\x18\x0b \x03(\x01\x12\x14\n\x0cisSetWeakThr\x18\x0c \x03(\x08\x12\x12\n\npeakWdwPts\x18\r \x03(\x05\x12\x0f\n\x07peakWdw\x18\x0e \x03(\x01\x12\x0c\n\x04isSD\x18\x0f \x02(\x08\"J\n\x10\x44\x41\x43StreamRequest\x12\x0b\n\x03\x44\x41\x43\x18\x01 \x02(\x05\x12\x12\n\nNtvChanIdx\x18\x02 \x02(\x05\x12\x15\n\rstreamGroupId\x18\x03 \x01(\t\"\xde\x01\n\x11\x45ventViewerConfig\x12\x15\n\reventViewerId\x18\x01 \x02(\t\x12\x15\n\rstreamGroupId\x18\x02 \x02(\t\x12\x19\n\x11triggerSysChanIdx\x18\x03 \x01(\x05\x12\x1a\n\x12triggerThresholdUV\x18\x04 \x01(\x01\x12\x14\n\x0cpreTriggerMs\x18\x05 \x02(\x01\x12\x15\n\rpostTriggerMs\x18\x06 \x02(\x01\x12\'\n\x0btriggerType\x18\x07 \x01(\x0e\x32\x12.allego.SignalType\x12\x0e\n\x06ntvIdx\x18\x08 \x01(\x05\"=\n\rEventViewerID\x12\x15\n\reventViewerId\x18\x01 \x02(\t\x12\x15\n\rstreamGroupId\x18\x02 \x02(\t\"D\n\x1aGetEventViewerEventRequest\x12\x15\n\reventViewerId\x18\x01 \x02(\t\x12\x0f\n\x07\x65ventId\x18\x02 \x02(\t\"Y\n\x14\x45ventViewerEventDesc\x12\x0f\n\x07\x65ventId\x18\x01 \x02(\t\x12\x18\n\x10triggerTimestamp\x18\x02 \x02(\x03\x12\x16\n\x0etimestampRange\x18\x03 \x03(\x03\"\x8f\x01\n\x10\x45ventViewerEvent\x12\x0f\n\x07\x65ventId\x18\x01 \x02(\t\x12\x18\n\x10triggerTimestamp\x18\x02 \x02(\x03\x12\x16\n\x0etimestampRange\x18\x03 \x03(\x03\x12#\n\x07signals\x18\x04 \x02(\x0b\x32\x12.allego.RawSignals\x12\x13\n\x0bsysChanIdxs\x18\x05 \x03(\x05\"a\n\x1aListEventViewerEventsReply\x12\x15\n\reventViewerId\x18\x01 \x02(\t\x12,\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x1c.allego.EventViewerEventDesc\"D\n\x15ListEventViewersReply\x12+\n\x0c\x65ventViewers\x18\x01 \x03(\x0b\x32\x15.allego.EventViewerID\"3\n\x1fStatusPollFieldsToUpdateRequest\x12\x10\n\x08\x63lientId\x18\x01 \x02(\t\"^\n\x18StatusPollFieldsToUpdate\x12\x10\n\x08\x63lientId\x18\x01 \x02(\t\x12\x30\n\x0e\x66ieldsToUpdate\x18\x02 \x03(\x0e\x32\x18.allego.StatusPollFields\"\xa5\x01\n\x17\x44\x61shboardCommandRequest\x12\'\n\x08\x64\x61shType\x18\x01 \x01(\x0e\x32\x15.allego.DashboardType\x12\x32\n\x04\x61rgs\x18\x02 \x01(\x0b\x32$.allego.DashboardCommandRequest.Args\x1a-\n\x04\x41rgs\x12%\n\x03\x63md\x18\x01 \x02(\x0e\x32\x18.allego.DashboardCommand\"]\n\x13SelTableSignalGroup\x12\r\n\x05index\x18\x01 \x02(\t\x12\x15\n\rcriterionDesc\x18\x02 \x02(\t\x12\x0f\n\x07ntvIdxs\x18\x03 \x03(\x03\x12\x0f\n\x07numSigs\x18\x04 \x02(\x03\"?\n\x13SelectorTablesReply\x12(\n\x03sig\x18\x01 \x03(\x0b\x32\x1b.allego.SelTableSignalGroup\"\x92\x03\n\x10\x44\x61taSourceStatus\x12%\n\x04type\x18\x01 \x02(\x0e\x32\x17.allego.SignalGroupType\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12\x16\n\x0etimestampRange\x18\x03 \x03(\x03\x12\x10\n\x08\x64uration\x18\x04 \x02(\x01\x12(\n\x0bsignalGroup\x18\x06 \x02(\x0b\x32\x13.allego.SignalGroup\x12\x17\n\x0fnumTotalSamples\x18\x07 \x02(\x03\x12\x12\n\nsampleFreq\x18\t \x01(\x01\x12\x0b\n\x03uid\x18\n \x02(\t\x12\x16\n\x0e\x64\x61taSourceType\x18\x0b \x02(\t\x12(\n\x08\x66ileType\x18\x0c \x02(\x0e\x32\x16.allego.RadixFileTypes\x12\x0c\n\x04mode\x18\r \x02(\t\x12\r\n\x05label\x18\x0e \x02(\t\x12\x0c\n\x04path\x18\x0f \x02(\t\x12\x14\n\x0c\x62\x61seFileName\x18\x10 \x02(\t\x12\x1d\n\x02tR\x18\x11 \x01(\x0b\x32\x11.allego.TimeRange\x12\x14\n\x0ckpiDsourceID\x18\x12 \x01(\t*\xc2\x01\n\x0cStartupStage\x12\x1a\n\x16STAGE_LAUNCHING_SERVER\x10\x00\x12!\n\x1dSTAGE_INITIALIZING_COMPONENTS\x10\x01\x12\"\n\x1eSTAGE_CONSTRUCTING_SPIKESORTER\x10\x02\x12\x1a\n\x16STAGE_INITIALIZING_DAQ\x10\x03\x12#\n\x1fSTAGE_RESTORING_SAVED_WORKSPACE\x10\x04\x12\x0e\n\nSTAGE_DONE\x10\x05*n\n\x10\x44\x61taExportFormat\x12\x17\n\x13\x44\x41TA_EXPORT_UNKNOWN\x10\x00\x12\x13\n\x0f\x44\x41TA_EXPORT_NPY\x10\x01\x12\x16\n\x12\x44\x41TA_EXPORT_MATLAB\x10\x02\x12\x14\n\x10\x44\x41TA_EXPORT_PHY2\x10\x03*\xdd\x02\n\x0eRadixFileTypes\x12\x07\n\x03RHD\x10\x00\x12\x08\n\x04XDAT\x10\x01\x12\x07\n\x03\x43SV\x10\x02\x12\x08\n\x04HDF5\x10\x03\x12\x08\n\x04NEX5\x10\x04\x12\x07\n\x03NWB\x10\x05\x12\x10\n\x0c\x42IOINTERFACE\x10\x07\x12\r\n\tKILOSORT2\x10\x08\x12\x07\n\x03\x41NC\x10\t\x12\x0f\n\x0bSPKTRAIN_MU\x10\n\x12\x1b\n\x17\x42IO_RADIENS_EXPORT_HDF5\x10\x0b\x12\x1b\n\x17\x42IO_RADIENS_EXPORT_MAT5\x10\x0c\x12\x07\n\x03NSX\x10\r\x12\x07\n\x03PL2\x10\x0e\x12\x07\n\x03TDT\x10\x0f\x12\n\n\x06SPIKES\x10\x10\x12\x07\n\x03KPI\x10\x11\x12\x15\n\x11UNKNOWN_FILE_TYPE\x10\x12\x12\x0f\n\x0bMEAREC_HDF5\x10\x13\x12\x1c\n\x18OFFLINE_SORTER_SPKS_MAT5\x10\x14\x12\x0c\n\x08SPKS_NPY\x10\x15\x12\n\n\x06OE_DAT\x10\x16\x12\r\n\tSPKS_PHY2\x10\x17*1\n\nSignalType\x12\x07\n\x03PRI\x10\x00\x12\x07\n\x03\x41UX\x10\x01\x12\x07\n\x03\x44IN\x10\x02\x12\x08\n\x04\x44OUT\x10\x03*@\n\x0fResampleRoutine\x12\t\n\x05NAIVE\x10\x00\x12\r\n\tRETENTIVE\x10\x01\x12\x13\n\x0f\x45\x44GE_PRESERVING\x10\x02*>\n\x04Port\x12\x05\n\x01\x41\x10\x00\x12\x05\n\x01\x42\x10\x01\x12\x05\n\x01\x43\x10\x02\x12\x05\n\x01\x44\x10\x03\x12\x05\n\x01\x45\x10\x04\x12\x05\n\x01\x46\x10\x05\x12\x05\n\x01G\x10\x06\x12\x05\n\x01H\x10\x07*2\n\x0cWorkspaceApp\x12\n\n\x06\x41llego\x10\x00\x12\n\n\x06\x43urate\x10\x01\x12\n\n\x06Videre\x10\x02*\xa0\x01\n\x11WorkspaceCommands\x12\x0f\n\x0bWSPACE_Save\x10\x00\x12\x11\n\rWSPACE_SaveAs\x10\x01\x12\x11\n\rWSPACE_Export\x10\x02\x12\x11\n\rWSPACE_Import\x10\x03\x12\x11\n\rWSPACE_Delete\x10\x04\x12\x11\n\rWSPACE_Switch\x10\x07\x12\x1b\n\x17WSPACE_SwitchToLastUsed\x10\x08*C\n\x14GetWorkspaceCommands\x12\x13\n\x0fGET_WSPACE_List\x10\x01\x12\x16\n\x12GET_WSPACE_Current\x10\x02*8\n\x11RadiensServerType\x12\x10\n\x0c\x41llegoserver\x10\x00\x12\x11\n\rRadiensserver\x10\x01*\xdb\x01\n\x0fGrpcServiceType\x12\x0f\n\x0b\x41LLEGO_CORE\x10\x00\x12\x11\n\rALLEGO_PCACHE\x10\x01\x12\x0e\n\nALLEGO_KPI\x10\x02\x12\x12\n\x0e\x41LLEGO_NEURONS\x10\x03\x12\x10\n\x0cRADIENS_CORE\x10\x04\x12\x18\n\x14RADIENS_SPIKE_SORTER\x10\x05\x12\x0f\n\x0bRADIENS_DEV\x10\x06\x12\x16\n\x12RADIENS_DASHBOARDS\x10\x07\x12\x14\n\x10\x41LLEGO_LIFECYCLE\x10\x08\x12\x15\n\x11RADIENS_LIFECYCLE\x10\t*?\n\x0e\x44\x65vDatasetType\x12\x08\n\x04\x42\x41SE\x10\x00\x12\t\n\x05TRAIN\x10\x01\x12\x0e\n\nVALIDATION\x10\x02\x12\x08\n\x04TEST\x10\x03*C\n\rPSDWindowType\x12\x0f\n\x0bHAMMING_p01\x10\x00\x12\x0f\n\x0bHAMMING_p05\x10\x01\x12\x10\n\x0cPASS_THROUGH\x10\x02*\x1e\n\nPSDScaling\x12\x10\n\x0cPSD_ABSOLUTE\x10\x00*X\n\x0e\x44\x61taSourceSort\x12\x10\n\x0c\x44SOURCE_DATE\x10\x00\x12\x10\n\x0c\x44SOURCE_NAME\x10\x01\x12\x10\n\x0c\x44SOURCE_SIZE\x10\x02\x12\x10\n\x0c\x44SOURCE_TYPE\x10\x03*.\n\x0fSignalGroupType\x12\x11\n\rPRIMARY_CACHE\x10\x00\x12\x08\n\x04\x46ILE\x10\x03*\x81\x01\n\x07\x44SPType\x12\x0b\n\x07LOWPASS\x10\x00\x12\x0c\n\x08HIGHPASS\x10\x01\x12\x0c\n\x08\x42\x41NDPASS\x10\x02\x12\t\n\x05NOTCH\x10\x03\x12\x0c\n\x08\x42\x41NDSTOP\x10\x04\x12\x07\n\x03\x43\x41R\x10\x05\x12\x15\n\x11VIRTUAL_REFERENCE\x10\x06\x12\x14\n\x10PAIRED_REFERENCE\x10\x07*K\n\x0b\x46ilterStage\x12\x12\n\x0eSTAGE_HARDWARE\x10\x00\x12\n\n\x06STAGE1\x10\x01\x12\n\n\x06STAGE2\x10\x02\x12\x10\n\x0cSPIKE_SORTER\x10\x03*\xd3\x02\n\x0e\x46\x65\x61tureLicense\x12\x1a\n\x16\x46\x65\x61t_NoLicenseRequired\x10\x00\x12\x0c\n\x08\x46\x65\x61t_Any\x10\x01\x12\x0f\n\x0b\x46\x65\x61t_Power9\x10\x02\x12\x11\n\rFeat_RadixAPI\x10\x03\x12\x0e\n\nFeat_Scope\x10\x04\x12\x13\n\x0f\x46\x65\x61t_Electrodes\x10\x05\x12\x13\n\x0f\x46\x65\x61t_HDSnapshot\x10\x06\x12\x12\n\x0e\x46\x65\x61t_Impedance\x10\x07\x12\x10\n\x0c\x46\x65\x61t_Monitor\x10\x08\x12\x16\n\x12\x46\x65\x61t_SignalMetrics\x10\t\x12\x19\n\x15\x46\x65\x61t_SignalProcessing\x10\n\x12\x0f\n\x0b\x46\x65\x61t_System\x10\x0b\x12\x12\n\x0e\x46\x65\x61t_SpikeGrid\x10\x0c\x12\x14\n\x10\x46\x65\x61t_SpikeSorter\x10\r\x12\x0f\n\x0b\x46\x65\x61t_Raster\x10\x0e\x12\x14\n\x10\x46\x65\x61t_ThreeDModel\x10\x0f*\xed\x01\n\x10SummaryStatsEnum\x12\x10\n\x0cSS_STAT_MEAN\x10\x00\x12\x0e\n\nSS_STAT_SD\x10\x01\x12\x10\n\x0cSS_STAT_MODE\x10\x02\x12\x0f\n\x0bSS_STAT_MIN\x10\x03\x12\x0f\n\x0bSS_STAT_MAX\x10\x04\x12\x16\n\x12SS_STAT_MODE_COUNT\x10\x05\x12\x12\n\x0eSS_STAT_MEDIAN\x10\x06\x12\x0f\n\x0bSS_STAT_Q25\x10\x07\x12\x0f\n\x0bSS_STAT_Q75\x10\x08\x12\x10\n\x0cSS_STAT_SKEW\x10\t\x12\x14\n\x10SS_STAT_KURTOSIS\x10\n\x12\r\n\tSS_STAT_N\x10\x0b*_\n\x0eKpiMetricsMode\x12\x18\n\x14Kpi_MetricsMode_Base\x10\x00\x12\x17\n\x13Kpi_MetricsMode_Avg\x10\x01\x12\x1a\n\x16Kpi_MetricsMode_Stream\x10\x02*\xa1\x06\n\x0eKpiMetricsEnum\x12\x0f\n\x0bKPI_NUM_PTS\x10\x00\x12\x13\n\x0fKPI_NUM_PTS_ISI\x10\x01\x12\x0f\n\x0bKPI_DUR_SEC\x10\x02\x12\x0c\n\x08KPI_MEAN\x10\x03\x12\x0b\n\x07KPI_MIN\x10\x04\x12\x0f\n\x0bKPI_MIN_ISI\x10\x05\x12\x0b\n\x07KPI_MAX\x10\x06\x12\x0f\n\x0bKPI_MAX_ISI\x10\x07\x12\x0f\n\x0bKPI_MAX_ABS\x10\x08\x12\x13\n\x0fKPI_MAX_ABS_ISI\x10\t\x12\x15\n\x11KPI_TIMESTAMP_MIN\x10\n\x12\x15\n\x11KPI_TIMESTAMP_MAX\x10\x0b\x12\x18\n\x14KPI_MAX_MIN_DIFF_ABS\x10\x0c\x12\x1c\n\x18KPI_MAX_MIN_DIFF_ABS_ISI\x10\r\x12\n\n\x06KPI_SD\x10\x0e\x12\x0e\n\nKPI_SD_ISI\x10\x0f\x12\x0b\n\x07KPI_VAR\x10\x10\x12\x0f\n\x0bKPI_VAR_ISI\x10\x11\x12\x0b\n\x07KPI_RMS\x10\x12\x12\x0f\n\x0bKPI_RMS_ISI\x10\x13\x12\x10\n\x0cKPI_NOISE_UV\x10\x14\x12\x0b\n\x07KPI_SNR\x10\x15\x12\x12\n\x0eKPI_NUM_EVENTS\x10\x16\x12\x12\n\x0eKPI_EVENT_RATE\x10\x17\x12\x11\n\rKPI_EVENT_MAX\x10\x18\x12\x11\n\rKPI_EVENT_MIN\x10\x19\x12\x15\n\x11KPI_EVENT_MAX_ABS\x10\x1a\x12\x1e\n\x1aKPI_EVENT_MAX_MIN_DIFF_ABS\x10\x1b\x12\x1b\n\x17KPI_EVENT_TIMESTAMP_MIN\x10\x1c\x12\x1b\n\x17KPI_EVENT_TIMESTAMP_MAX\x10\x1d\x12\x1f\n\x1bKPI_EVENT_TIMESTAMP_MAX_ABS\x10\x1e\x12(\n$KPI_EVENT_TIMESTAMP_MAX_MIN_DIFF_ABS\x10\x1f\x12\x10\n\x0cKPI_MEAN_MAX\x10 \x12\x10\n\x0cKPI_MEAN_MIN\x10!\x12\x14\n\x10KPI_MEAN_MAX_ABS\x10\"\x12#\n\x1fKPI_EVENT_MEAN_MAX_MIN_DIFF_ABS\x10#\x12\"\n\x1eKPI_MAX_MIN_DIFF_ABS_AMPLIFIED\x10$*\x8b\x01\n\x13KpiMetricsStatsEnum\x12\x1e\n\x1aKPI_BDL_METRICS_STATS_MEAN\x10\x00\x12\x1d\n\x19KPI_BDL_METRICS_STATS_MAX\x10\x01\x12\x1d\n\x19KPI_BDL_METRICS_STATS_MIN\x10\x02\x12\x16\n\x12KPI_BDL_METRICS_SD\x10\x03*\xc0\x02\n\x19KpiBundlePacketsStatsEnum\x12\x14\n\x10KPI_BDL_NUM_SIGS\x10\x00\x12\x13\n\x0fKPI_BDL_DUR_SEC\x10\x01\x12\x1d\n\x19KPI_BDL_NUM_SIGS_W_EVENTS\x10\x02\x12\x15\n\x11KPI_BDL_SIG_YIELD\x10\x03\x12\x13\n\x0fKPI_BDL_RMS_AVG\x10\x04\x12\x13\n\x0fKPI_BDL_SNR_AVG\x10\x05\x12\x13\n\x0fKPI_BDL_SIG_MAX\x10\x06\x12\x13\n\x0fKPI_BDL_SIG_MIN\x10\x07\x12\x18\n\x14KPI_BDL_NOISE_UV_AVG\x10\x08\x12\x1c\n\x18KPI_BDL_NUM_EVENTS_TOTAL\x10\t\x12\x1a\n\x16KPI_BDL_NUM_EVENTS_AVG\x10\n\x12\x1a\n\x16KPI_BDL_EVENT_RATE_AVG\x10\x0b*F\n\x10TimeRangeSelMode\x12\x0e\n\nTRS_SUBSET\x10\x00\x12\x0f\n\x0bTRS_TO_HEAD\x10\x01\x12\x11\n\rTRS_FROM_HEAD\x10\x02*N\n\x16OutfitterComponentType\x12\x16\n\x12OUTFIT_COMP_SENSOR\x10\x00\x12\x1c\n\x18OUTFIT_COMP_SPIKE_SORTER\x10\x01*}\n\x0eWorldNodeLabel\x12\x12\n\x0eWORLD_NODE_ORG\x10\x01\x12\x12\n\x0eWORLD_NODE_LAB\x10\x02\x12\x13\n\x0fWORLD_NODE_USER\x10\x03\x12\x18\n\x14WORLD_NODE_CAT_PROBE\x10\x04\x12\x14\n\x10WORLD_NODE_PROBE\x10\x05*\'\n\x0eWorldEdgeLabel\x12\x15\n\x11WORLD_EDGE_MEMBER\x10\x01*`\n\x12WorldEdgeDirection\x12\x18\n\x14WORLD_EDGE_DIR_RIGHT\x10\x01\x12\x17\n\x13WORLD_EDGE_DIR_LEFT\x10\x02\x12\x17\n\x13WORLD_EDGE_DIR_BOTH\x10\x03*\x9f\x01\n\x0cUserRoleType\x12\x0b\n\x07USER_PI\x10\x01\x12\x12\n\x0eUSER_SCIENTIST\x10\x02\x12\x11\n\rUSER_POST_DOC\x10\x03\x12\x15\n\x11USER_GRAD_STUDENT\x10\x04\x12\x13\n\x0fUSER_UG_STUDENT\x10\x05\x12\x10\n\x0cUSER_MANAGER\x10\x06\x12\r\n\tUSER_TECH\x10\x07\x12\x0e\n\nUSER_OTHER\x10\x08*G\n\rManageNodeCmd\x12\x10\n\x0cNODE_CMD_NEW\x10\x01\x12\x12\n\x0eNODE_CMD_MERGE\x10\x02\x12\x10\n\x0cNODE_CMD_DEL\x10\x03*\xe8\x01\n\rWorldQueryCmd\x12\x15\n\x11WQ_LIST_ALL_USERS\x10\x01\x12\x14\n\x10WQ_LIST_ALL_LABS\x10\x02\x12\x14\n\x10WQ_LIST_ALL_ORGS\x10\x03\x12\x1a\n\x16WQ_LIST_ALL_CAT_PROBES\x10\x04\x12\x16\n\x12WQ_LIST_ALL_PROBES\x10\x05\x12\x18\n\x14WQ_CAT_PROBE_BY_NAME\x10\x06\x12\x11\n\rWQ_USER_BY_ID\x10\x07\x12\x19\n\x15WQ_USER_AND_LAB_BY_ID\x10\x08\x12\x18\n\x14WQ2_LIST_ALL_DEVICES\x10\x1e*\xa2\x02\n\x11TransformNodeType\x12\x10\n\x0cNOTCH_FILTER\x10\x00\x12\x13\n\x0f\x42\x41NDPASS_FILTER\x10\x01\x12\x13\n\x0f\x42\x41NDSTOP_FILTER\x10\x02\x12\x13\n\x0fHIGHPASS_FILTER\x10\x03\x12\x12\n\x0eLOWPASS_FILTER\x10\x04\x12\x0e\n\nPAIRED_REF\x10\x05\x12\x0f\n\x0bVIRTUAL_REF\x10\x06\x12\x0b\n\x07\x43\x41R_REF\x10\x07\x12\x0e\n\nSLICE_TIME\x10\t\x12\x12\n\x0eSLICE_CHANNELS\x10\n\x12\n\n\x06SOURCE\x10\x0b\x12\x08\n\x04SINK\x10\x0c\x12\x0e\n\nDOWNSAMPLE\x10\r\x12\x10\n\x0cREMAP_SENSOR\x10\x0e\x12\x0f\n\x0b\x42ULK_SOURCE\x10\x0f\x12\r\n\tBULK_SINK\x10\x10*\xdf\x01\n\x17SpikeSorterParamCommand\x12\x14\n\x10SORTER_THR_LEVEL\x10\x01\x12\x17\n\x13SORTER_THR_LEVEL_SD\x10\x04\x12\x12\n\x0eSORTER_THR_WDW\x10\x08\x12\x19\n\x15SORTER_WEAK_THR_LEVEL\x10\n\x12\x1c\n\x18SORTER_WEAK_THR_LEVEL_SD\x10\r\x12\x11\n\rSORTER_SHADOW\x10\x11\x12\x17\n\x13SORTER_THR_ACTIVATE\x10\x13\x12\x1c\n\x18SORTER_WEAK_THR_ACTIVATE\x10\x15*\xee\x03\n\x10StatusPollFields\x12\x19\n\x15PORT_CONNECTION_STATE\x10\x00\x12\x14\n\x10RECORDING_ERRORS\x10\x01\x12\x15\n\x11STREAM_TIME_RANGE\x10\x02\x12\x11\n\rSTREAM_STATUS\x10\x03\x12\x11\n\rRECORD_STATUS\x10\x04\x12\x10\n\x0cIS_CONNECTED\x10\x06\x12\x0e\n\nRECORD_DUR\x10\x07\x12\x11\n\rBACKBONE_MODE\x10\t\x12\x10\n\x0cSIGNAL_GROUP\x10\n\x12\x14\n\x10SINAPS_REGISTERS\x10\x0b\x12\x14\n\x10RECORDING_CONFIG\x10\x0c\x12\x0b\n\x07\x46ILTERS\x10\r\x12\x17\n\x13\x45VENT_THRESH_PARAMS\x10\x0e\x12\x10\n\x0c\x44\x41\x43_REGISTER\x10\x0f\x12\x10\n\x0c\x44IO_REGISTER\x10\x10\x12\x10\n\x0cTRIGGER_MODE\x10\x11\x12\x11\n\rCABLE_LENGTHS\x10\x12\x12\x11\n\rEVENT_VIEWERS\x10\x13\x12\x0f\n\x0bSAMPLE_RATE\x10\x14\x12\x0e\n\nALL_FIELDS\x10\x15\x12\x16\n\x12SPIKE_SORTER_STATE\x10\x16\x12\x0f\n\x0bSTIM_PARAMS\x10\x17\x12\x19\n\x15SPIKE_SORTER_WARNINGS\x10\x18\x12\x12\n\x0eSTIM_STEP_SIZE\x10\x19*\x1b\n\rDashboardType\x12\n\n\x06\x44\x41SH_1\x10\x00*N\n\x10\x44\x61shboardCommand\x12\x11\n\rDASH_CMD_OPEN\x10\x00\x12\x12\n\x0e\x44\x41SH_CMD_CLOSE\x10\x01\x12\x13\n\x0f\x44\x41SH_CMD_UPDATE\x10\x02\x42\x15Z\x13internal/radix/grpc')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\023internal/radix/grpc'
  _globals['_GETWORKSPACEREPLY_WORKSPACEDESCENTRY']._loaded_options = None
  _globals['_GETWORKSPACEREPLY_WORKSPACEDESCENTRY']._serialized_options = b'8\001'
  _globals['_SERVERSPEC_SERVICEENTRY']._loaded_options = None
  _globals['_SERVERSPEC_SERVICEENTRY']._serialized_options = b'8\001'
  _globals['_GETSORTERIDMAPREPLY_SIGTOSORTMAPENTRY']._loaded_options = None
  _globals['_GETSORTERIDMAPREPLY_SIGTOSORTMAPENTRY']._serialized_options = b'8\001'
  _globals['_SIGNALGROUPUNITS_UNITSENTRY']._loaded_options = None
  _globals['_SIGNALGROUPUNITS_UNITSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATESIGNALGROUPREQUEST'].fields_by_name['ntvChanIdx']._loaded_options = None
  _globals['_UPDATESIGNALGROUPREQUEST'].fields_by_name['ntvChanIdx']._serialized_options = b'\020\001'
  _globals['_STARTUPSTAGE']._serialized_start=25980
  _globals['_STARTUPSTAGE']._serialized_end=26174
  _globals['_DATAEXPORTFORMAT']._serialized_start=26176
  _globals['_DATAEXPORTFORMAT']._serialized_end=26286
  _globals['_RADIXFILETYPES']._serialized_start=26289
  _globals['_RADIXFILETYPES']._serialized_end=26638
  _globals['_SIGNALTYPE']._serialized_start=26640
  _globals['_SIGNALTYPE']._serialized_end=26689
  _globals['_RESAMPLEROUTINE']._serialized_start=26691
  _globals['_RESAMPLEROUTINE']._serialized_end=26755
  _globals['_PORT']._serialized_start=26757
  _globals['_PORT']._serialized_end=26819
  _globals['_WORKSPACEAPP']._serialized_start=26821
  _globals['_WORKSPACEAPP']._serialized_end=26871
  _globals['_WORKSPACECOMMANDS']._serialized_start=26874
  _globals['_WORKSPACECOMMANDS']._serialized_end=27034
  _globals['_GETWORKSPACECOMMANDS']._serialized_start=27036
  _globals['_GETWORKSPACECOMMANDS']._serialized_end=27103
  _globals['_RADIENSSERVERTYPE']._serialized_start=27105
  _globals['_RADIENSSERVERTYPE']._serialized_end=27161
  _globals['_GRPCSERVICETYPE']._serialized_start=27164
  _globals['_GRPCSERVICETYPE']._serialized_end=27383
  _globals['_DEVDATASETTYPE']._serialized_start=27385
  _globals['_DEVDATASETTYPE']._serialized_end=27448
  _globals['_PSDWINDOWTYPE']._serialized_start=27450
  _globals['_PSDWINDOWTYPE']._serialized_end=27517
  _globals['_PSDSCALING']._serialized_start=27519
  _globals['_PSDSCALING']._serialized_end=27549
  _globals['_DATASOURCESORT']._serialized_start=27551
  _globals['_DATASOURCESORT']._serialized_end=27639
  _globals['_SIGNALGROUPTYPE']._serialized_start=27641
  _globals['_SIGNALGROUPTYPE']._serialized_end=27687
  _globals['_DSPTYPE']._serialized_start=27690
  _globals['_DSPTYPE']._serialized_end=27819
  _globals['_FILTERSTAGE']._serialized_start=27821
  _globals['_FILTERSTAGE']._serialized_end=27896
  _globals['_FEATURELICENSE']._serialized_start=27899
  _globals['_FEATURELICENSE']._serialized_end=28238
  _globals['_SUMMARYSTATSENUM']._serialized_start=28241
  _globals['_SUMMARYSTATSENUM']._serialized_end=28478
  _globals['_KPIMETRICSMODE']._serialized_start=28480
  _globals['_KPIMETRICSMODE']._serialized_end=28575
  _globals['_KPIMETRICSENUM']._serialized_start=28578
  _globals['_KPIMETRICSENUM']._serialized_end=29379
  _globals['_KPIMETRICSSTATSENUM']._serialized_start=29382
  _globals['_KPIMETRICSSTATSENUM']._serialized_end=29521
  _globals['_KPIBUNDLEPACKETSSTATSENUM']._serialized_start=29524
  _globals['_KPIBUNDLEPACKETSSTATSENUM']._serialized_end=29844
  _globals['_TIMERANGESELMODE']._serialized_start=29846
  _globals['_TIMERANGESELMODE']._serialized_end=29916
  _globals['_OUTFITTERCOMPONENTTYPE']._serialized_start=29918
  _globals['_OUTFITTERCOMPONENTTYPE']._serialized_end=29996
  _globals['_WORLDNODELABEL']._serialized_start=29998
  _globals['_WORLDNODELABEL']._serialized_end=30123
  _globals['_WORLDEDGELABEL']._serialized_start=30125
  _globals['_WORLDEDGELABEL']._serialized_end=30164
  _globals['_WORLDEDGEDIRECTION']._serialized_start=30166
  _globals['_WORLDEDGEDIRECTION']._serialized_end=30262
  _globals['_USERROLETYPE']._serialized_start=30265
  _globals['_USERROLETYPE']._serialized_end=30424
  _globals['_MANAGENODECMD']._serialized_start=30426
  _globals['_MANAGENODECMD']._serialized_end=30497
  _globals['_WORLDQUERYCMD']._serialized_start=30500
  _globals['_WORLDQUERYCMD']._serialized_end=30732
  _globals['_TRANSFORMNODETYPE']._serialized_start=30735
  _globals['_TRANSFORMNODETYPE']._serialized_end=31025
  _globals['_SPIKESORTERPARAMCOMMAND']._serialized_start=31028
  _globals['_SPIKESORTERPARAMCOMMAND']._serialized_end=31251
  _globals['_STATUSPOLLFIELDS']._serialized_start=31254
  _globals['_STATUSPOLLFIELDS']._serialized_end=31748
  _globals['_DASHBOARDTYPE']._serialized_start=31750
  _globals['_DASHBOARDTYPE']._serialized_end=31777
  _globals['_DASHBOARDCOMMAND']._serialized_start=31779
  _globals['_DASHBOARDCOMMAND']._serialized_end=31857
  _globals['_HARDWAREUUIDRESPONSE']._serialized_start=57
  _globals['_HARDWAREUUIDRESPONSE']._serialized_end=101
  _globals['_OFFLINELICENSESTATUS']._serialized_start=103
  _globals['_OFFLINELICENSESTATUS']._serialized_end=167
  _globals['_FIRMWAREVERSION']._serialized_start=169
  _globals['_FIRMWAREVERSION']._serialized_end=236
  _globals['_RADIXENVIRONMENT']._serialized_start=239
  _globals['_RADIXENVIRONMENT']._serialized_end=377
  _globals['_STARTUPSTATUS']._serialized_start=379
  _globals['_STARTUPSTATUS']._serialized_end=458
  _globals['_STANDARDREQUEST']._serialized_start=460
  _globals['_STANDARDREQUEST']._serialized_end=493
  _globals['_STANDARDREPLY']._serialized_start=495
  _globals['_STANDARDREPLY']._serialized_end=542
  _globals['_DACOFFREQUEST']._serialized_start=544
  _globals['_DACOFFREQUEST']._serialized_end=582
  _globals['_WORKSPACEDESCRIPTOR']._serialized_start=585
  _globals['_WORKSPACEDESCRIPTOR']._serialized_end=771
  _globals['_WORKSPACECONTROLREQUEST']._serialized_start=774
  _globals['_WORKSPACECONTROLREQUEST']._serialized_end=993
  _globals['_GETWORKSPACEREQUEST']._serialized_start=996
  _globals['_GETWORKSPACEREQUEST']._serialized_end=1207
  _globals['_GETWORKSPACEREPLY']._serialized_start=1210
  _globals['_GETWORKSPACEREPLY']._serialized_end=1381
  _globals['_GETWORKSPACEREPLY_WORKSPACEDESCENTRY']._serialized_start=1300
  _globals['_GETWORKSPACEREPLY_WORKSPACEDESCENTRY']._serialized_end=1381
  _globals['_GETRADIENSSERVERSREQUEST']._serialized_start=1383
  _globals['_GETRADIENSSERVERSREQUEST']._serialized_end=1479
  _globals['_SERVERSPEC']._serialized_start=1482
  _globals['_SERVERSPEC']._serialized_end=1761
  _globals['_SERVERSPEC_GRPCSERVICE']._serialized_start=1623
  _globals['_SERVERSPEC_GRPCSERVICE']._serialized_end=1650
  _globals['_SERVERSPEC_SPAWNEDPROCESS']._serialized_start=1652
  _globals['_SERVERSPEC_SPAWNEDPROCESS']._serialized_end=1681
  _globals['_SERVERSPEC_SERVICEENTRY']._serialized_start=1683
  _globals['_SERVERSPEC_SERVICEENTRY']._serialized_end=1761
  _globals['_RADIENSSERVERSREPLY']._serialized_start=1763
  _globals['_RADIENSSERVERSREPLY']._serialized_end=1869
  _globals['_SIGNALGROUPIDREQUEST']._serialized_start=1871
  _globals['_SIGNALGROUPIDREQUEST']._serialized_end=1916
  _globals['_SIGNALMAP']._serialized_start=1919
  _globals['_SIGNALMAP']._serialized_end=2115
  _globals['_GPIOCHANNELCOUNT']._serialized_start=2117
  _globals['_GPIOCHANNELCOUNT']._serialized_end=2178
  _globals['_PORTCHANNELCOUNT']._serialized_start=2180
  _globals['_PORTCHANNELCOUNT']._serialized_end=2248
  _globals['_SETPORTREQUEST']._serialized_start=2250
  _globals['_SETPORTREQUEST']._serialized_end=2331
  _globals['_HDSNAPSHOTREQUEST']._serialized_start=2334
  _globals['_HDSNAPSHOTREQUEST']._serialized_end=2738
  _globals['_HDSNAPSHOTREQUEST_SELECTEDSIGNALS']._serialized_start=2700
  _globals['_HDSNAPSHOTREQUEST_SELECTEDSIGNALS']._serialized_end=2738
  _globals['_HDSNAPSHOTREQUEST2']._serialized_start=2741
  _globals['_HDSNAPSHOTREQUEST2']._serialized_end=2891
  _globals['_RADIENSPYGRAPHICSARGS']._serialized_start=2893
  _globals['_RADIENSPYGRAPHICSARGS']._serialized_end=2969
  _globals['_PSDREQUEST']._serialized_start=2972
  _globals['_PSDREQUEST']._serialized_end=3321
  _globals['_PSD']._serialized_start=3324
  _globals['_PSD']._serialized_end=3613
  _globals['_RADIENSPYGRAPHICSREQUEST']._serialized_start=3615
  _globals['_RADIENSPYGRAPHICSREQUEST']._serialized_end=3716
  _globals['_SIGSELECTOR']._serialized_start=3718
  _globals['_SIGSELECTOR']._serialized_end=3812
  _globals['_HDSNAPSHOTMETA']._serialized_start=3814
  _globals['_HDSNAPSHOTMETA']._serialized_end=3907
  _globals['_HDSNAPSHOT']._serialized_start=3910
  _globals['_HDSNAPSHOT']._serialized_end=4197
  _globals['_HDSNAPSHOT2']._serialized_start=4199
  _globals['_HDSNAPSHOT2']._serialized_end=4263
  _globals['_GETSIGNALSREQUEST']._serialized_start=4266
  _globals['_GETSIGNALSREQUEST']._serialized_end=4946
  _globals['_GETSIGNALSREQUEST_GETSIGSPARAMS']._serialized_start=4368
  _globals['_GETSIGNALSREQUEST_GETSIGSPARAMS']._serialized_end=4946
  _globals['_RAWSIGNALS']._serialized_start=4948
  _globals['_RAWSIGNALS']._serialized_end=5039
  _globals['_SIGNALS2']._serialized_start=5042
  _globals['_SIGNALS2']._serialized_end=5273
  _globals['_LISTSENSORSPECSREQUEST']._serialized_start=5275
  _globals['_LISTSENSORSPECSREQUEST']._serialized_end=5350
  _globals['_LISTSENSORSPECSREPLY']._serialized_start=5353
  _globals['_LISTSENSORSPECSREPLY']._serialized_end=5614
  _globals['_LISTSENSORSPECSREPLY_SPECWITHCHANNELCOUNT']._serialized_start=5556
  _globals['_LISTSENSORSPECSREPLY_SPECWITHCHANNELCOUNT']._serialized_end=5614
  _globals['_LISTDATASOURCESREQUEST']._serialized_start=5616
  _globals['_LISTDATASOURCESREQUEST']._serialized_end=5716
  _globals['_SORTMAP']._serialized_start=5718
  _globals['_SORTMAP']._serialized_end=5746
  _globals['_GETSIGNALGROUPIDSREPLY']._serialized_start=5748
  _globals['_GETSIGNALGROUPIDSREPLY']._serialized_end=5810
  _globals['_GETSORTERIDMAPREPLY']._serialized_start=5813
  _globals['_GETSORTERIDMAPREPLY']._serialized_end=5973
  _globals['_GETSORTERIDMAPREPLY_SIGTOSORTMAPENTRY']._serialized_start=5905
  _globals['_GETSORTERIDMAPREPLY_SIGTOSORTMAPENTRY']._serialized_end=5973
  _globals['_DATASOURCE']._serialized_start=5976
  _globals['_DATASOURCE']._serialized_end=6151
  _globals['_FILEDESCRIPTOR']._serialized_start=6154
  _globals['_FILEDESCRIPTOR']._serialized_end=6290
  _globals['_TIMESPEC']._serialized_start=6293
  _globals['_TIMESPEC']._serialized_end=6501
  _globals['_TIMESPEC_TIMERANGEL']._serialized_start=6415
  _globals['_TIMESPEC_TIMERANGEL']._serialized_end=6446
  _globals['_TIMESPEC_TIMESTAMPRANGEL']._serialized_start=6448
  _globals['_TIMESPEC_TIMESTAMPRANGEL']._serialized_end=6489
  _globals['_SIGNALSPEC']._serialized_start=6504
  _globals['_SIGNALSPEC']._serialized_end=6694
  _globals['_SIGNALSPEC_SITENUML']._serialized_start=6620
  _globals['_SIGNALSPEC_SITENUML']._serialized_end=6647
  _globals['_SIGNALSPEC_NTVCHANIDXL']._serialized_start=6649
  _globals['_SIGNALSPEC_NTVCHANIDXL']._serialized_end=6682
  _globals['_CHANNELRECORD']._serialized_start=6697
  _globals['_CHANNELRECORD']._serialized_end=7477
  _globals['_XYCOORD']._serialized_start=7479
  _globals['_XYCOORD']._serialized_end=7510
  _globals['_XYZCOORD']._serialized_start=7512
  _globals['_XYZCOORD']._serialized_end=7555
  _globals['_SENSOR']._serialized_start=7558
  _globals['_SENSOR']._serialized_end=7943
  _globals['_SENSOR_WIREFRAME']._serialized_start=7834
  _globals['_SENSOR_WIREFRAME']._serialized_end=7943
  _globals['_SENSORPORTSPEC']._serialized_start=7946
  _globals['_SENSORPORTSPEC']._serialized_end=8226
  _globals['_SIGNALGROUPUNITS']._serialized_start=8228
  _globals['_SIGNALGROUPUNITS']._serialized_end=8344
  _globals['_SIGNALGROUPUNITS_UNITSENTRY']._serialized_start=8300
  _globals['_SIGNALGROUPUNITS_UNITSENTRY']._serialized_end=8344
  _globals['_SIGNALGROUP']._serialized_start=8347
  _globals['_SIGNALGROUP']._serialized_end=8629
  _globals['_CREATESIGNALGROUPREQUEST']._serialized_start=8632
  _globals['_CREATESIGNALGROUPREQUEST']._serialized_end=8767
  _globals['_SUBOPSORT']._serialized_start=8769
  _globals['_SUBOPSORT']._serialized_end=8884
  _globals['_SUBOPSORT_SORTFIELD']._serialized_start=8825
  _globals['_SUBOPSORT_SORTFIELD']._serialized_end=8884
  _globals['_UPDATESIGNALGROUPREQUEST']._serialized_start=8887
  _globals['_UPDATESIGNALGROUPREQUEST']._serialized_end=9308
  _globals['_UPDATESIGNALGROUPREQUEST_OPERATION']._serialized_start=9189
  _globals['_UPDATESIGNALGROUPREQUEST_OPERATION']._serialized_end=9255
  _globals['_UPDATESIGNALGROUPREQUEST_SUBOPERATION']._serialized_start=9257
  _globals['_UPDATESIGNALGROUPREQUEST_SUBOPERATION']._serialized_end=9292
  _globals['_SLICESIGNALGROUPSPEC']._serialized_start=9310
  _globals['_SLICESIGNALGROUPSPEC']._serialized_end=9394
  _globals['_SLICESIGNALGROUPREQUEST']._serialized_start=9396
  _globals['_SLICESIGNALGROUPREQUEST']._serialized_end=9484
  _globals['_SLICESIGNALGROUPREPLY']._serialized_start=9487
  _globals['_SLICESIGNALGROUPREPLY']._serialized_end=9623
  _globals['_LICENSESTATUS']._serialized_start=9625
  _globals['_LICENSESTATUS']._serialized_end=9640
  _globals['_SETDSPGROUPREQUEST']._serialized_start=9642
  _globals['_SETDSPGROUPREQUEST']._serialized_end=9759
  _globals['_DSPPARAMS']._serialized_start=9762
  _globals['_DSPPARAMS']._serialized_end=10190
  _globals['_DSPPARAMS_FREQSPECBAND']._serialized_start=10129
  _globals['_DSPPARAMS_FREQSPECBAND']._serialized_end=10178
  _globals['_DSPGROUP']._serialized_start=10193
  _globals['_DSPGROUP']._serialized_end=10366
  _globals['_SETSENSORREQUEST']._serialized_start=10369
  _globals['_SETSENSORREQUEST']._serialized_end=10547
  _globals['_SENSORPOSITIONTCS']._serialized_start=10549
  _globals['_SENSORPOSITIONTCS']._serialized_end=10658
  _globals['_SETSENSORPOSITIONTCSREQUEST']._serialized_start=10661
  _globals['_SETSENSORPOSITIONTCSREQUEST']._serialized_end=10805
  _globals['_SITEPOSITIONTCS']._serialized_start=10807
  _globals['_SITEPOSITIONTCS']._serialized_end=10877
  _globals['_SETSITEPOSITIONSTCSREQUEST']._serialized_start=10879
  _globals['_SETSITEPOSITIONSTCSREQUEST']._serialized_end=11006
  _globals['_FEATURESTARTSTOPREQUEST']._serialized_start=11008
  _globals['_FEATURESTARTSTOPREQUEST']._serialized_end=11097
  _globals['_PRIVACYREPLY']._serialized_start=11099
  _globals['_PRIVACYREPLY']._serialized_end=11132
  _globals['_SETPRIVACYREQUEST']._serialized_start=11134
  _globals['_SETPRIVACYREQUEST']._serialized_end=11172
  _globals['_DENSEMATRIX']._serialized_start=11174
  _globals['_DENSEMATRIX']._serialized_end=11229
  _globals['_HISTOGRAM']._serialized_start=11231
  _globals['_HISTOGRAM']._serialized_end=11323
  _globals['_KPIMETRICID']._serialized_start=11325
  _globals['_KPIMETRICID']._serialized_end=11414
  _globals['_TIMERANGE']._serialized_start=11417
  _globals['_TIMERANGE']._serialized_end=11550
  _globals['_BUNDLEREQ']._serialized_start=11552
  _globals['_BUNDLEREQ']._serialized_end=11649
  _globals['_KPIMETRICSREQ']._serialized_start=11651
  _globals['_KPIMETRICSREQ']._serialized_end=11756
  _globals['_KPIMETRICSDATA']._serialized_start=11759
  _globals['_KPIMETRICSDATA']._serialized_end=12119
  _globals['_KPIMETRICSDATA_METRICSTATS']._serialized_start=12054
  _globals['_KPIMETRICSDATA_METRICSTATS']._serialized_end=12119
  _globals['_KPIBUNDLEPACKETMETRICS']._serialized_start=12121
  _globals['_KPIBUNDLEPACKETMETRICS']._serialized_end=12240
  _globals['_KPIMETRICS']._serialized_start=12242
  _globals['_KPIMETRICS']._serialized_end=12325
  _globals['_SIGNALMETRICSPACKETREPLY']._serialized_start=12328
  _globals['_SIGNALMETRICSPACKETREPLY']._serialized_end=12518
  _globals['_KPICONTROLREQUEST']._serialized_start=12520
  _globals['_KPICONTROLREQUEST']._serialized_end=12619
  _globals['_SETKPIPARAMREQUEST']._serialized_start=12621
  _globals['_SETKPIPARAMREQUEST']._serialized_end=12679
  _globals['_GETKPISTATUSREQUEST']._serialized_start=12681
  _globals['_GETKPISTATUSREQUEST']._serialized_end=12725
  _globals['_KPISTANDARDREQUEST']._serialized_start=12727
  _globals['_KPISTANDARDREQUEST']._serialized_end=12766
  _globals['_KPIFILESTATUS']._serialized_start=12769
  _globals['_KPIFILESTATUS']._serialized_end=12955
  _globals['_KPIFILESTATUS_STATE']._serialized_start=12832
  _globals['_KPIFILESTATUS_STATE']._serialized_end=12955
  _globals['_KPIFILESTATUS2']._serialized_start=12958
  _globals['_KPIFILESTATUS2']._serialized_end=13688
  _globals['_KPIFILESTATUS2_KPI_STATE']._serialized_start=13041
  _globals['_KPIFILESTATUS2_KPI_STATE']._serialized_end=13421
  _globals['_KPIFILESTATUS2_DATASOURCE_STATE']._serialized_start=13423
  _globals['_KPIFILESTATUS2_DATASOURCE_STATE']._serialized_end=13536
  _globals['_KPIFILESTATUS2_KPIDATASOURCESTATESPEC']._serialized_start=13539
  _globals['_KPIFILESTATUS2_KPIDATASOURCESTATESPEC']._serialized_end=13688
  _globals['_KPIFILEMETADATA']._serialized_start=13691
  _globals['_KPIFILEMETADATA']._serialized_end=13966
  _globals['_KPIFILEMETADATA_STATE']._serialized_start=13759
  _globals['_KPIFILEMETADATA_STATE']._serialized_end=13966
  _globals['_KPISTATUSREPLY']._serialized_start=13969
  _globals['_KPISTATUSREPLY']._serialized_end=14308
  _globals['_SIGKPIPARAMRECORD']._serialized_start=14311
  _globals['_SIGKPIPARAMRECORD']._serialized_end=14669
  _globals['_ANNOTATEBUNDLE']._serialized_start=14671
  _globals['_ANNOTATEBUNDLE']._serialized_end=14745
  _globals['_PROJECTMETADATA']._serialized_start=14747
  _globals['_PROJECTMETADATA']._serialized_end=14840
  _globals['_SENSOREXTENDEDMETADATA']._serialized_start=14842
  _globals['_SENSOREXTENDEDMETADATA']._serialized_end=14893
  _globals['_GONUMMATRIXLIST']._serialized_start=14895
  _globals['_GONUMMATRIXLIST']._serialized_end=14932
  _globals['_RADIXMATRIXLIST']._serialized_start=14934
  _globals['_RADIXMATRIXLIST']._serialized_end=14988
  _globals['_RADIXMATRIX']._serialized_start=14990
  _globals['_RADIXMATRIX']._serialized_end=15032
  _globals['_RADIXMATRIXBYTES']._serialized_start=15034
  _globals['_RADIXMATRIXBYTES']._serialized_end=15081
  _globals['_RADIXSIGNALSLIST']._serialized_start=15083
  _globals['_RADIXSIGNALSLIST']._serialized_end=15139
  _globals['_RADIXSIGNALS']._serialized_start=15142
  _globals['_RADIXSIGNALS']._serialized_end=15311
  _globals['_VECTORSTRING']._serialized_start=15313
  _globals['_VECTORSTRING']._serialized_end=15338
  _globals['_VECTORFLOAT64']._serialized_start=15340
  _globals['_VECTORFLOAT64']._serialized_end=15366
  _globals['_VECTORSLICEFLOAT64']._serialized_start=15368
  _globals['_VECTORSLICEFLOAT64']._serialized_end=15439
  _globals['_LOGSYSKPISTATUSREPLY']._serialized_start=15442
  _globals['_LOGSYSKPISTATUSREPLY']._serialized_end=15792
  _globals['_KPICACHE']._serialized_start=15795
  _globals['_KPICACHE']._serialized_end=16175
  _globals['_LOGSYSKPITAILREPLY']._serialized_start=16178
  _globals['_LOGSYSKPITAILREPLY']._serialized_end=16556
  _globals['_KPIPORTINFO']._serialized_start=16558
  _globals['_KPIPORTINFO']._serialized_end=16609
  _globals['_KPITAILROWS']._serialized_start=16612
  _globals['_KPITAILROWS']._serialized_end=16984
  _globals['_WAREHOUSEHEALTHCHECKSPEC']._serialized_start=16986
  _globals['_WAREHOUSEHEALTHCHECKSPEC']._serialized_end=17028
  _globals['_OUTFITTERGETDEVICEREQUEST']._serialized_start=17030
  _globals['_OUTFITTERGETDEVICEREQUEST']._serialized_end=17070
  _globals['_SENSORCOMPREQUEST']._serialized_start=17073
  _globals['_SENSORCOMPREQUEST']._serialized_end=17231
  _globals['_REGISTERSENSORCOMPREQUEST']._serialized_start=17233
  _globals['_REGISTERSENSORCOMPREQUEST']._serialized_end=17355
  _globals['_SAVESENSORCOMPINSTANCEREQUEST']._serialized_start=17358
  _globals['_SAVESENSORCOMPINSTANCEREQUEST']._serialized_end=17504
  _globals['_PROBEDESC']._serialized_start=17506
  _globals['_PROBEDESC']._serialized_end=17544
  _globals['_HEADSTAGEDESC']._serialized_start=17546
  _globals['_HEADSTAGEDESC']._serialized_end=17588
  _globals['_GETSENSORCOMPREPLY']._serialized_start=17590
  _globals['_GETSENSORCOMPREPLY']._serialized_end=17686
  _globals['_PROBESPEC']._serialized_start=17688
  _globals['_PROBESPEC']._serialized_end=17808
  _globals['_HEADSTAGESPEC']._serialized_start=17811
  _globals['_HEADSTAGESPEC']._serialized_end=17947
  _globals['_PROBEMODEL']._serialized_start=17950
  _globals['_PROBEMODEL']._serialized_end=18540
  _globals['_PROBEMODEL_PROBESITEDESC']._serialized_start=18187
  _globals['_PROBEMODEL_PROBESITEDESC']._serialized_end=18409
  _globals['_PROBEMODEL_PROBEWIREFRAME']._serialized_start=18411
  _globals['_PROBEMODEL_PROBEWIREFRAME']._serialized_end=18505
  _globals['_PROBEMODEL_PROBEPTXY']._serialized_start=18507
  _globals['_PROBEMODEL_PROBEPTXY']._serialized_end=18540
  _globals['_PROBEMETADATA']._serialized_start=18542
  _globals['_PROBEMETADATA']._serialized_end=18637
  _globals['_HEADSTAGEMODEL']._serialized_start=18640
  _globals['_HEADSTAGEMODEL']._serialized_end=18772
  _globals['_HEADSTAGEMODEL_HEADSTAGEROW']._serialized_start=18721
  _globals['_HEADSTAGEMODEL_HEADSTAGEROW']._serialized_end=18772
  _globals['_HEADSTAGEMETADATA']._serialized_start=18774
  _globals['_HEADSTAGEMETADATA']._serialized_end=18793
  _globals['_USERPROFILE']._serialized_start=18795
  _globals['_USERPROFILE']._serialized_end=18848
  _globals['_GETCURRENTPROFILEREPLY']._serialized_start=18850
  _globals['_GETCURRENTPROFILEREPLY']._serialized_end=18916
  _globals['_GETALLPROFILESREPLY']._serialized_start=18918
  _globals['_GETALLPROFILESREPLY']._serialized_end=18982
  _globals['_SETCURRENTPROFILEREQUEST']._serialized_start=18984
  _globals['_SETCURRENTPROFILEREQUEST']._serialized_end=19029
  _globals['_MANAGENODEORGPAYLOAD']._serialized_start=19032
  _globals['_MANAGENODEORGPAYLOAD']._serialized_end=19168
  _globals['_MANAGENODEORGREQUEST']._serialized_start=19170
  _globals['_MANAGENODEORGREQUEST']._serialized_end=19275
  _globals['_MANAGENODEORGREPLY']._serialized_start=19277
  _globals['_MANAGENODEORGREPLY']._serialized_end=19360
  _globals['_MANAGENODELABPAYLOAD']._serialized_start=19363
  _globals['_MANAGENODELABPAYLOAD']._serialized_end=19525
  _globals['_MANAGENODELABREQUEST']._serialized_start=19527
  _globals['_MANAGENODELABREQUEST']._serialized_end=19632
  _globals['_MANAGENODELABREPLY']._serialized_start=19634
  _globals['_MANAGENODELABREPLY']._serialized_end=19717
  _globals['_MANAGENODEUSERPAYLOAD']._serialized_start=19720
  _globals['_MANAGENODEUSERPAYLOAD']._serialized_end=19873
  _globals['_MANAGENODEUSERREQUEST']._serialized_start=19875
  _globals['_MANAGENODEUSERREQUEST']._serialized_end=19982
  _globals['_MANAGENODEUSERREPLY']._serialized_start=19984
  _globals['_MANAGENODEUSERREPLY']._serialized_end=20069
  _globals['_CATALOGPROBEPAYLOAD']._serialized_start=20071
  _globals['_CATALOGPROBEPAYLOAD']._serialized_end=20125
  _globals['_PROBENODEREQUEST']._serialized_start=20127
  _globals['_PROBENODEREQUEST']._serialized_end=20220
  _globals['_PROBENODEREPLY']._serialized_start=20222
  _globals['_PROBENODEREPLY']._serialized_end=20277
  _globals['_PROBEPAYLOAD']._serialized_start=20279
  _globals['_PROBEPAYLOAD']._serialized_end=20326
  _globals['_EDGEPAYLOAD']._serialized_start=20329
  _globals['_EDGEPAYLOAD']._serialized_end=20622
  _globals['_EDGEPAYLOAD_GENERICNODE']._serialized_start=20532
  _globals['_EDGEPAYLOAD_GENERICNODE']._serialized_end=20622
  _globals['_WORLDEDGEREQUEST']._serialized_start=20624
  _globals['_WORLDEDGEREQUEST']._serialized_end=20680
  _globals['_WORLDEDGEREPLY']._serialized_start=20682
  _globals['_WORLDEDGEREPLY']._serialized_end=20698
  _globals['_QUERYWORLDREQUEST']._serialized_start=20700
  _globals['_QUERYWORLDREQUEST']._serialized_end=20769
  _globals['_QUERYWORLDREC']._serialized_start=20772
  _globals['_QUERYWORLDREC']._serialized_end=21002
  _globals['_QUERYWORLDREPLY']._serialized_start=21004
  _globals['_QUERYWORLDREPLY']._serialized_end=21061
  _globals['_HIGHLOWPASSTRANSFORMPARAMS']._serialized_start=21063
  _globals['_HIGHLOWPASSTRANSFORMPARAMS']._serialized_end=21125
  _globals['_BANDTRANSFORMPARAMS']._serialized_start=21127
  _globals['_BANDTRANSFORMPARAMS']._serialized_end=21208
  _globals['_NOTCHTRANSFORMPARAMS']._serialized_start=21210
  _globals['_NOTCHTRANSFORMPARAMS']._serialized_end=21295
  _globals['_CARTRANSFORMPARAMS']._serialized_start=21297
  _globals['_CARTRANSFORMPARAMS']._serialized_end=21317
  _globals['_VIRTUALREFTRANSFORMPARAMS']._serialized_start=21319
  _globals['_VIRTUALREFTRANSFORMPARAMS']._serialized_end=21369
  _globals['_PAIREDREFTRANSFORMPARAMS']._serialized_start=21371
  _globals['_PAIREDREFTRANSFORMPARAMS']._serialized_end=21446
  _globals['_DATASOURCESINKTRANSFORMPARAMS']._serialized_start=21448
  _globals['_DATASOURCESINKTRANSFORMPARAMS']._serialized_end=21565
  _globals['_BULKDATASOURCETRANSFORMPARAMS']._serialized_start=21567
  _globals['_BULKDATASOURCETRANSFORMPARAMS']._serialized_end=21656
  _globals['_BULKDATASINKTRANSFORMPARAMS']._serialized_start=21658
  _globals['_BULKDATASINKTRANSFORMPARAMS']._serialized_end=21759
  _globals['_SLICETIMETRANSFORMPARAMS']._serialized_start=21761
  _globals['_SLICETIMETRANSFORMPARAMS']._serialized_end=21823
  _globals['_SLICECHANNELSTRANSFORMPARAMS']._serialized_start=21825
  _globals['_SLICECHANNELSTRANSFORMPARAMS']._serialized_end=21935
  _globals['_DOWNSAMPLETRANSFORMPARAMS']._serialized_start=21937
  _globals['_DOWNSAMPLETRANSFORMPARAMS']._serialized_end=21986
  _globals['_REMAPSENSORTRANSFORMPARAMS']._serialized_start=21989
  _globals['_REMAPSENSORTRANSFORMPARAMS']._serialized_end=22225
  _globals['_REMAPSENSORTRANSFORMPARAMS_SENSORSPEC']._serialized_start=22100
  _globals['_REMAPSENSORTRANSFORMPARAMS_SENSORSPEC']._serialized_end=22225
  _globals['_POSITION']._serialized_start=22227
  _globals['_POSITION']._serialized_end=22259
  _globals['_TRANSFORMNODE']._serialized_start=22262
  _globals['_TRANSFORMNODE']._serialized_end=23206
  _globals['_TRANSFORMEDGE']._serialized_start=23208
  _globals['_TRANSFORMEDGE']._serialized_end=23285
  _globals['_PROTOCOL']._serialized_start=23287
  _globals['_PROTOCOL']._serialized_end=23403
  _globals['_PROTOCOLREQUEST']._serialized_start=23405
  _globals['_PROTOCOLREQUEST']._serialized_end=23442
  _globals['_RENAMEPROTOCOLREQUEST']._serialized_start=23444
  _globals['_RENAMEPROTOCOLREQUEST']._serialized_end=23510
  _globals['_GETALLPROTOCOLSREPLY']._serialized_start=23512
  _globals['_GETALLPROTOCOLSREPLY']._serialized_end=23571
  _globals['_APPLYPROTOCOLPROGRESS']._serialized_start=23574
  _globals['_APPLYPROTOCOLPROGRESS']._serialized_end=23717
  _globals['_SPIKESORTERSETPARAMREQUEST']._serialized_start=23720
  _globals['_SPIKESORTERSETPARAMREQUEST']._serialized_end=23874
  _globals['_SPIKESORTERSETPARAMSREQUEST']._serialized_start=23876
  _globals['_SPIKESORTERSETPARAMSREQUEST']._serialized_end=23957
  _globals['_SPIKESORTERPARAMCOMMANDRECORD']._serialized_start=23960
  _globals['_SPIKESORTERPARAMCOMMANDRECORD']._serialized_end=24255
  _globals['_DACSTREAMREQUEST']._serialized_start=24257
  _globals['_DACSTREAMREQUEST']._serialized_end=24331
  _globals['_EVENTVIEWERCONFIG']._serialized_start=24334
  _globals['_EVENTVIEWERCONFIG']._serialized_end=24556
  _globals['_EVENTVIEWERID']._serialized_start=24558
  _globals['_EVENTVIEWERID']._serialized_end=24619
  _globals['_GETEVENTVIEWEREVENTREQUEST']._serialized_start=24621
  _globals['_GETEVENTVIEWEREVENTREQUEST']._serialized_end=24689
  _globals['_EVENTVIEWEREVENTDESC']._serialized_start=24691
  _globals['_EVENTVIEWEREVENTDESC']._serialized_end=24780
  _globals['_EVENTVIEWEREVENT']._serialized_start=24783
  _globals['_EVENTVIEWEREVENT']._serialized_end=24926
  _globals['_LISTEVENTVIEWEREVENTSREPLY']._serialized_start=24928
  _globals['_LISTEVENTVIEWEREVENTSREPLY']._serialized_end=25025
  _globals['_LISTEVENTVIEWERSREPLY']._serialized_start=25027
  _globals['_LISTEVENTVIEWERSREPLY']._serialized_end=25095
  _globals['_STATUSPOLLFIELDSTOUPDATEREQUEST']._serialized_start=25097
  _globals['_STATUSPOLLFIELDSTOUPDATEREQUEST']._serialized_end=25148
  _globals['_STATUSPOLLFIELDSTOUPDATE']._serialized_start=25150
  _globals['_STATUSPOLLFIELDSTOUPDATE']._serialized_end=25244
  _globals['_DASHBOARDCOMMANDREQUEST']._serialized_start=25247
  _globals['_DASHBOARDCOMMANDREQUEST']._serialized_end=25412
  _globals['_DASHBOARDCOMMANDREQUEST_ARGS']._serialized_start=25367
  _globals['_DASHBOARDCOMMANDREQUEST_ARGS']._serialized_end=25412
  _globals['_SELTABLESIGNALGROUP']._serialized_start=25414
  _globals['_SELTABLESIGNALGROUP']._serialized_end=25507
  _globals['_SELECTORTABLESREPLY']._serialized_start=25509
  _globals['_SELECTORTABLESREPLY']._serialized_end=25572
  _globals['_DATASOURCESTATUS']._serialized_start=25575
  _globals['_DATASOURCESTATUS']._serialized_end=25977
# @@protoc_insertion_point(module_scope)



"""Proto <-> domain converters — the ONLY place importing both proto and domain types."""

from radiens_core._converters._channels import (
    channel_metadata_from_proto,
)
from radiens_core._converters._common_enums import (
    backbone_mode_from_proto,
    backbone_mode_to_proto,
    port_from_proto,
    port_to_proto,
    record_mode_from_proto,
    record_mode_to_proto,
    stream_mode_from_proto,
    stream_mode_to_proto,
)
from radiens_core._converters._core_config import (
    core_config_from_proto,
    set_core_config_to_proto,
)
from radiens_core._converters._dac import (
    analog_out_register_from_proto,
    dac_highpass_to_proto,
    set_dac_gain_to_proto,
    set_dac_off_to_proto,
    set_dac_stream_to_proto,
)
from radiens_core._converters._dataset import (
    dataset_metadata_from_proto,
    file_type_to_proto,
)
from radiens_core._converters._kpi import (
    build_bundle_req,
    kpi_metric_id_to_proto,
    kpi_metrics_result_from_proto,
    kpi_status_from_proto,
)
from radiens_core._converters._record_state import (
    record_state_request_to_proto,
)
from radiens_core._converters._recording_config import (
    recording_config_from_proto,
    recording_config_to_proto,
)
from radiens_core._converters._restart import restart_request_to_proto
from radiens_core._converters._signals import (
    sig_select_to_proto,
    signal_arrays_from_hd_snapshot,
    signal_arrays_from_signals2,
)
from radiens_core._converters._sinaps import (
    build_flash_sinaps_proto,
    build_load_all_mosi_proto,
    build_read_wire_out_proto,
    sinaps_status_registers_from_proto,
    wire_out_value_from_proto,
)
from radiens_core._converters._status import (
    backbone_status_from_proto,
)
from radiens_core._converters._stim import (
    stim_params_from_proto,
    stim_params_to_proto,
)
from radiens_core._converters._stim_step import (
    stim_step_from_proto,
    stim_step_request_to_proto,
)
from radiens_core._converters._stream_state import (
    stream_state_request_to_proto,
)
from radiens_core._converters._time_range import time_range_to_proto
from radiens_core._converters._trigger_control import (
    manual_stim_trigger_request_to_proto,
    manual_stim_trigger_toggle_request_to_proto,
    set_trigger_state_request_to_proto,
    trigger_state_from_proto,
)
from radiens_core._converters._validation import validate_proto

__all__ = [
    "analog_out_register_from_proto",
    "backbone_mode_from_proto",
    "backbone_mode_to_proto",
    "backbone_status_from_proto",
    "build_bundle_req",
    "build_flash_sinaps_proto",
    "build_load_all_mosi_proto",
    "build_read_wire_out_proto",
    "channel_metadata_from_proto",
    "core_config_from_proto",
    "dac_highpass_to_proto",
    "dataset_metadata_from_proto",
    "file_type_to_proto",
    "kpi_metric_id_to_proto",
    "kpi_metrics_result_from_proto",
    "kpi_status_from_proto",
    "manual_stim_trigger_request_to_proto",
    "manual_stim_trigger_toggle_request_to_proto",
    "port_from_proto",
    "port_to_proto",
    "record_mode_from_proto",
    "record_mode_to_proto",
    "record_state_request_to_proto",
    "recording_config_from_proto",
    "recording_config_to_proto",
    "restart_request_to_proto",
    "set_core_config_to_proto",
    "set_dac_gain_to_proto",
    "set_dac_off_to_proto",
    "set_dac_stream_to_proto",
    "set_trigger_state_request_to_proto",
    "sig_select_to_proto",
    "signal_arrays_from_hd_snapshot",
    "signal_arrays_from_signals2",
    "sinaps_status_registers_from_proto",
    "stim_params_from_proto",
    "stim_params_to_proto",
    "stim_step_from_proto",
    "stim_step_request_to_proto",
    "stream_mode_from_proto",
    "stream_mode_to_proto",
    "stream_state_request_to_proto",
    "time_range_to_proto",
    "trigger_state_from_proto",
    "validate_proto",
    "wire_out_value_from_proto",
]
